# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/rrule.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'schedule/v1/rrule.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17schedule/v1/rrule.proto\x12\x0bschedule.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"9\n\x03Nth\x12\x0b\n\x03nth\x18\x01 \x01(\x05\x12%\n\x07weekday\x18\x02 \x01(\x0e\x32\x14.schedule.v1.Weekday\".\n\x05\x45very\x12%\n\x07weekday\x18\x01 \x01(\x0e\x32\x14.schedule.v1.Weekday\"[\n\tByWeekday\x12#\n\x05\x65very\x18\x01 \x01(\x0b\x32\x12.schedule.v1.EveryH\x00\x12\x1f\n\x03nth\x18\x02 \x01(\x0b\x32\x10.schedule.v1.NthH\x00\x42\x08\n\x06group0\"f\n\x08RRuleEnd\x12\x0f\n\x05\x63ount\x18\x01 \x01(\rH\x00\x12+\n\x05until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x12\n\x08until_dt\x18\x03 \x01(\tH\x00\x42\x08\n\x06group0\"\xc0\x01\n\x05RRule\x12)\n\tfrequency\x18\x01 \x01(\x0e\x32\x16.schedule.v1.Frequency\x12\x10\n\x08interval\x18\x02 \x01(\r\x12(\n\trrule_end\x18\x03 \x01(\x0b\x32\x15.schedule.v1.RRuleEnd\x12$\n\x08\x62y_month\x18\x04 \x03(\x0e\x32\x12.schedule.v1.Month\x12*\n\nby_weekday\x18\x05 \x03(\x0b\x32\x16.schedule.v1.ByWeekday*\xb6\x01\n\x07Weekday\x12\x17\n\x13WEEKDAY_UNSPECIFIED\x10\x00\x12\x12\n\x0eWEEKDAY_MONDAY\x10\x01\x12\x13\n\x0fWEEKDAY_TUESDAY\x10\x02\x12\x15\n\x11WEEKDAY_WEDNESDAY\x10\x03\x12\x14\n\x10WEEKDAY_THURSDAY\x10\x04\x12\x12\n\x0eWEEKDAY_FRIDAY\x10\x05\x12\x14\n\x10WEEKDAY_SATURDAY\x10\x06\x12\x12\n\x0eWEEKDAY_SUNDAY\x10\x07*\xf8\x01\n\x05Month\x12\x15\n\x11MONTH_UNSPECIFIED\x10\x00\x12\x11\n\rMONTH_JANUARY\x10\x01\x12\x12\n\x0eMONTH_FEBRUARY\x10\x02\x12\x0f\n\x0bMONTH_MARCH\x10\x03\x12\x0f\n\x0bMONTH_APRIL\x10\x04\x12\r\n\tMONTH_MAY\x10\x05\x12\x0e\n\nMONTH_JUNE\x10\x06\x12\x0e\n\nMONTH_JULY\x10\x07\x12\x10\n\x0cMONTH_AUGUST\x10\x08\x12\x13\n\x0fMONTH_SEPTEMBER\x10\t\x12\x11\n\rMONTH_OCTOBER\x10\n\x12\x12\n\x0eMONTH_NOVEMBER\x10\x0b\x12\x12\n\x0eMONTH_DECEMBER\x10\x0c*\xac\x01\n\tFrequency\x12\x19\n\x15\x46REQUENCY_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46REQUENCY_YEARLY\x10\x01\x12\x15\n\x11\x46REQUENCY_MONTHLY\x10\x02\x12\x14\n\x10\x46REQUENCY_WEEKLY\x10\x03\x12\x13\n\x0f\x46REQUENCY_DAILY\x10\x04\x12\x14\n\x10\x46REQUENCY_HOURLY\x10\x05\x12\x16\n\x12\x46REQUENCY_MINUTELY\x10\x06\x42\x66\n\x0bschedule.v1B\nRruleProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.rrule_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013schedule.v1B\nRruleProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_WEEKDAY']._serialized_start=573
  _globals['_WEEKDAY']._serialized_end=755
  _globals['_MONTH']._serialized_start=758
  _globals['_MONTH']._serialized_end=1006
  _globals['_FREQUENCY']._serialized_start=1009
  _globals['_FREQUENCY']._serialized_end=1181
  _globals['_NTH']._serialized_start=73
  _globals['_NTH']._serialized_end=130
  _globals['_EVERY']._serialized_start=132
  _globals['_EVERY']._serialized_end=178
  _globals['_BYWEEKDAY']._serialized_start=180
  _globals['_BYWEEKDAY']._serialized_end=271
  _globals['_RRULEEND']._serialized_start=273
  _globals['_RRULEEND']._serialized_end=375
  _globals['_RRULE']._serialized_start=378
  _globals['_RRULE']._serialized_end=570
# @@protoc_insertion_point(module_scope)