# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import user_invitation_pb2 as user__account_dot_v2_dot_user__invitation__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in user_account/v2/user_invitation_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UserInvitationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeleteInvitation = channel.unary_unary(
                '/user_account.v2.UserInvitationService/DeleteInvitation',
                request_serializer=user__account_dot_v2_dot_user__invitation__pb2.DeleteInvitationRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__invitation__pb2.DeleteInvitationResponse.FromString,
                _registered_method=True)
        self.InviteUserToHousehold = channel.unary_unary(
                '/user_account.v2.UserInvitationService/InviteUserToHousehold',
                request_serializer=user__account_dot_v2_dot_user__invitation__pb2.InviteUserToHouseholdRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__invitation__pb2.InviteUserToHouseholdResponse.FromString,
                _registered_method=True)
        self.AcceptInvitation = channel.unary_unary(
                '/user_account.v2.UserInvitationService/AcceptInvitation',
                request_serializer=user__account_dot_v2_dot_user__invitation__pb2.AcceptInvitationRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__invitation__pb2.AcceptInvitationResponse.FromString,
                _registered_method=True)
        self.GetInvitationsByHouseholdId = channel.unary_unary(
                '/user_account.v2.UserInvitationService/GetInvitationsByHouseholdId',
                request_serializer=user__account_dot_v2_dot_user__invitation__pb2.GetInvitationsByHouseholdIdRequest.SerializeToString,
                response_deserializer=user__account_dot_v2_dot_user__invitation__pb2.GetInvitationsByHouseholdIdResponse.FromString,
                _registered_method=True)


class UserInvitationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeleteInvitation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InviteUserToHousehold(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptInvitation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInvitationsByHouseholdId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserInvitationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DeleteInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInvitation,
                    request_deserializer=user__account_dot_v2_dot_user__invitation__pb2.DeleteInvitationRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__invitation__pb2.DeleteInvitationResponse.SerializeToString,
            ),
            'InviteUserToHousehold': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteUserToHousehold,
                    request_deserializer=user__account_dot_v2_dot_user__invitation__pb2.InviteUserToHouseholdRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__invitation__pb2.InviteUserToHouseholdResponse.SerializeToString,
            ),
            'AcceptInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptInvitation,
                    request_deserializer=user__account_dot_v2_dot_user__invitation__pb2.AcceptInvitationRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__invitation__pb2.AcceptInvitationResponse.SerializeToString,
            ),
            'GetInvitationsByHouseholdId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInvitationsByHouseholdId,
                    request_deserializer=user__account_dot_v2_dot_user__invitation__pb2.GetInvitationsByHouseholdIdRequest.FromString,
                    response_serializer=user__account_dot_v2_dot_user__invitation__pb2.GetInvitationsByHouseholdIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'user_account.v2.UserInvitationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('user_account.v2.UserInvitationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserInvitationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeleteInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserInvitationService/DeleteInvitation',
            user__account_dot_v2_dot_user__invitation__pb2.DeleteInvitationRequest.SerializeToString,
            user__account_dot_v2_dot_user__invitation__pb2.DeleteInvitationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InviteUserToHousehold(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserInvitationService/InviteUserToHousehold',
            user__account_dot_v2_dot_user__invitation__pb2.InviteUserToHouseholdRequest.SerializeToString,
            user__account_dot_v2_dot_user__invitation__pb2.InviteUserToHouseholdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcceptInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserInvitationService/AcceptInvitation',
            user__account_dot_v2_dot_user__invitation__pb2.AcceptInvitationRequest.SerializeToString,
            user__account_dot_v2_dot_user__invitation__pb2.AcceptInvitationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetInvitationsByHouseholdId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user_account.v2.UserInvitationService/GetInvitationsByHouseholdId',
            user__account_dot_v2_dot_user__invitation__pb2.GetInvitationsByHouseholdIdRequest.SerializeToString,
            user__account_dot_v2_dot_user__invitation__pb2.GetInvitationsByHouseholdIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)