# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/power/controller/v1/current_transformer.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/power/controller/v1/current_transformer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4device/power/controller/v1/current_transformer.proto\x12\x1a\x64\x65vice.power.controller.v1\"\x90\x01\n\x0cThreePhaseCt\x12\x30\n\x04port\x18\x01 \x01(\x0e\x32\".device.power.controller.v1.CtPort\x12N\n\x0borientation\x18\x03 \x01(\x0e\x32\x39.device.power.controller.v1.CurrentTransformerOrientation\"\xbd\x01\n\rThreePhaseCts\x12\x38\n\x06phase1\x18\x01 \x01(\x0b\x32(.device.power.controller.v1.ThreePhaseCt\x12\x38\n\x06phase2\x18\x02 \x01(\x0b\x32(.device.power.controller.v1.ThreePhaseCt\x12\x38\n\x06phase3\x18\x03 \x01(\x0b\x32(.device.power.controller.v1.ThreePhaseCt\"\\\n\nOnePhaseCt\x12N\n\x0borientation\x18\x02 \x01(\x0e\x32\x39.device.power.controller.v1.CurrentTransformerOrientation\"\xaa\x01\n\x1f\x43urrentTransformerConfiguration\x12;\n\tone_phase\x18\x01 \x01(\x0b\x32&.device.power.controller.v1.OnePhaseCtH\x00\x12@\n\x0bthree_phase\x18\x02 \x01(\x0b\x32).device.power.controller.v1.ThreePhaseCtsH\x00\x42\x08\n\x06group0\"\xbc\x01\n\x17\x43urrentTransformerState\x12;\n\nscan_state\x18\x01 \x01(\x0e\x32\'.device.power.controller.v1.CtScanState\x12\x10\n\x08\x63t_ratio\x18\x02 \x01(\r\x12R\n\rconfiguration\x18\x03 \x01(\x0b\x32;.device.power.controller.v1.CurrentTransformerConfiguration*h\n\x0b\x43tScanState\x12\x1d\n\x19\x43T_SCAN_STATE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43T_SCAN_STATE_NOT_SCANNING\x10\x01\x12\x1a\n\x16\x43T_SCAN_STATE_SCANNING\x10\x02*\xa5\x01\n\x1d\x43urrentTransformerOrientation\x12/\n+CURRENT_TRANSFORMER_ORIENTATION_UNSPECIFIED\x10\x00\x12(\n$CURRENT_TRANSFORMER_ORIENTATION_LEFT\x10\x01\x12)\n%CURRENT_TRANSFORMER_ORIENTATION_RIGHT\x10\x02*N\n\x06\x43tPort\x12\x17\n\x13\x43T_PORT_UNSPECIFIED\x10\x00\x12\r\n\tCT_PORT_1\x10\x01\x12\r\n\tCT_PORT_2\x10\x02\x12\r\n\tCT_PORT_3\x10\x03\x42\xc0\x01\n\x1a\x64\x65vice.power.controller.v1B\x17\x43urrentTransformerProtoP\x01\xa2\x02\x03\x44PC\xaa\x02\x1a\x44\x65vice.Power.Controller.V1\xca\x02\x1a\x44\x65vice\\Power\\Controller\\V1\xe2\x02&Device\\Power\\Controller\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::Power::Controller::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.power.controller.v1.current_transformer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032device.power.controller.v1B\027CurrentTransformerProtoP\001\242\002\003DPC\252\002\032Device.Power.Controller.V1\312\002\032Device\\Power\\Controller\\V1\342\002&Device\\Power\\Controller\\V1\\GPBMetadata\352\002\035Device::Power::Controller::V1'
  _globals['_CTSCANSTATE']._serialized_start=881
  _globals['_CTSCANSTATE']._serialized_end=985
  _globals['_CURRENTTRANSFORMERORIENTATION']._serialized_start=988
  _globals['_CURRENTTRANSFORMERORIENTATION']._serialized_end=1153
  _globals['_CTPORT']._serialized_start=1155
  _globals['_CTPORT']._serialized_end=1233
  _globals['_THREEPHASECT']._serialized_start=85
  _globals['_THREEPHASECT']._serialized_end=229
  _globals['_THREEPHASECTS']._serialized_start=232
  _globals['_THREEPHASECTS']._serialized_end=421
  _globals['_ONEPHASECT']._serialized_start=423
  _globals['_ONEPHASECT']._serialized_end=515
  _globals['_CURRENTTRANSFORMERCONFIGURATION']._serialized_start=518
  _globals['_CURRENTTRANSFORMERCONFIGURATION']._serialized_end=688
  _globals['_CURRENTTRANSFORMERSTATE']._serialized_start=691
  _globals['_CURRENTTRANSFORMERSTATE']._serialized_end=879
# @@protoc_insertion_point(module_scope)