# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: util/v1/type_of_day.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'util/v1/type_of_day.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19util/v1/type_of_day.proto\x12\x07util.v1*Z\n\tTypeOfDay\x12\x1b\n\x17TYPE_OF_DAY_UNSPECIFIED\x10\x00\x12\x17\n\x13TYPE_OF_DAY_WEEKDAY\x10\x01\x12\x17\n\x13TYPE_OF_DAY_WEEKEND\x10\x02\x42V\n\x07util.v1B\x0eTypeOfDayProtoP\x01\xa2\x02\x03UXX\xaa\x02\x07Util.V1\xca\x02\x07Util\\V1\xe2\x02\x13Util\\V1\\GPBMetadata\xea\x02\x08Util::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'util.v1.type_of_day_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\007util.v1B\016TypeOfDayProtoP\001\242\002\003UXX\252\002\007Util.V1\312\002\007Util\\V1\342\002\023Util\\V1\\GPBMetadata\352\002\010Util::V1'
  _globals['_TYPEOFDAY']._serialized_start=38
  _globals['_TYPEOFDAY']._serialized_end=128
# @@protoc_insertion_point(module_scope)