# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/features.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/state/v1/features.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(device/heat_pump/state/v1/features.proto\x12\x19\x64\x65vice.heat_pump.state.v1\"P\n\x08\x46\x65\x61tures\x12\x44\n\x10\x66\x65\x61ture_versions\x18\x01 \x03(\x0b\x32*.device.heat_pump.state.v1.FeatureVersions\"\x8d\x01\n\x0f\x46\x65\x61tureVersions\x12\x33\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0e\x32\".device.heat_pump.state.v1.Feature\x12\x45\n\x12supported_versions\x18\x02 \x03(\x0e\x32).device.heat_pump.state.v1.FeatureVersion*\x83\x01\n\x07\x46\x65\x61ture\x12\x17\n\x13\x46\x45\x41TURE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x46\x45\x41TURE_LEGIONELLA\x10\x01\x12\x13\n\x0f\x46\x45\x41TURE_HEATING\x10\x02\x12\x15\n\x11\x46\x45\x41TURE_SCHEDULER\x10\x03\x12\x1b\n\x17\x46\x45\x41TURE_STATE_REPORTING\x10\x04*\xbb\x01\n\x0e\x46\x65\x61tureVersion\x12\x1f\n\x1b\x46\x45\x41TURE_VERSION_UNSPECIFIED\x10\x00\x12\x15\n\x11\x46\x45\x41TURE_VERSION_1\x10\x01\x12\x15\n\x11\x46\x45\x41TURE_VERSION_2\x10\x02\x12\x15\n\x11\x46\x45\x41TURE_VERSION_3\x10\x03\x12\x15\n\x11\x46\x45\x41TURE_VERSION_4\x10\x04\x12\x15\n\x11\x46\x45\x41TURE_VERSION_5\x10\x05\x12\x15\n\x11\x46\x45\x41TURE_VERSION_6\x10\x06\x42\xad\x01\n\x19\x64\x65vice.heat_pump.state.v1B\rFeaturesProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.features_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031device.heat_pump.state.v1B\rFeaturesProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_FEATURE']._serialized_start=298
  _globals['_FEATURE']._serialized_end=429
  _globals['_FEATUREVERSION']._serialized_start=432
  _globals['_FEATUREVERSION']._serialized_end=619
  _globals['_FEATURES']._serialized_start=71
  _globals['_FEATURES']._serialized_end=151
  _globals['_FEATUREVERSIONS']._serialized_start=154
  _globals['_FEATUREVERSIONS']._serialized_end=295
# @@protoc_insertion_point(module_scope)