# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/command_error.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/command_error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...modbus.v1 import exception_pb2 as device_dot_heat__pump_dot_modbus_dot_v1_dot_exception__pb2
from . import set_telemetry_interval_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__telemetry__interval__pb2
from . import set_scheduled_heat_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__scheduled__heat__curve__deltas__pb2
from . import set_room_temp_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__room__temp__setpoint__delta__pb2
from . import set_room_supply_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__room__supply__setpoint__delta__pb2
from . import set_dhw_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__dhw__setpoint__delta__pb2
from . import missing_field_error_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_missing__field__error__pb2
from . import database_error_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_database__error__pb2
from . import configure_heat_pump_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_configure__heat__pump__pb2
from . import ccv_error_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_ccv__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/device/heat_pump/command/v1/command_error.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\x1a*device/heat_pump/modbus/v1/exception.proto\x1a\x38\x64\x65vice/heat_pump/command/v1/set_telemetry_interval.proto\x1a\x41\x64\x65vice/heat_pump/command/v1/set_scheduled_heat_curve_deltas.proto\x1a>device/heat_pump/command/v1/set_room_temp_setpoint_delta.proto\x1a@device/heat_pump/command/v1/set_room_supply_setpoint_delta.proto\x1a\x38\x64\x65vice/heat_pump/command/v1/set_dhw_setpoint_delta.proto\x1a\x35\x64\x65vice/heat_pump/command/v1/missing_field_error.proto\x1a\x30\x64\x65vice/heat_pump/command/v1/database_error.proto\x1a\x35\x64\x65vice/heat_pump/command/v1/configure_heat_pump.proto\x1a+device/heat_pump/command/v1/ccv_error.proto\"\x91\x07\n\x0c\x43ommandError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x12\n\nwill_retry\x18\x08 \x01(\x08\x12?\n\x10modbus_exception\x18\t \x01(\x0e\x32%.device.heat_pump.modbus.v1.Exception\x12@\n\x0c\x63onfig_error\x18\x04 \x01(\x0b\x32(.device.heat_pump.command.v1.ConfigErrorH\x00\x12]\n\x1cset_dhw_setpoint_delta_error\x18\x05 \x01(\x0e\x32\x35.device.heat_pump.command.v1.SetDhwSetpointDeltaErrorH\x00\x12l\n$set_room_supply_setpoint_delta_error\x18\x06 \x01(\x0e\x32<.device.heat_pump.command.v1.SetRoomSupplySetpointDeltaErrorH\x00\x12:\n\tccv_error\x18\x07 \x01(\x0b\x32%.device.heat_pump.command.v1.CcvErrorH\x00\x12\x44\n\x0e\x64\x61tabase_error\x18\n \x01(\x0b\x32*.device.heat_pump.command.v1.DatabaseErrorH\x00\x12M\n\x13missing_field_error\x18\x0b \x01(\x0b\x32..device.heat_pump.command.v1.MissingFieldErrorH\x00\x12h\n\"set_room_temp_setpoint_delta_error\x18\x0c \x01(\x0e\x32:.device.heat_pump.command.v1.SetRoomTempSetpointDeltaErrorH\x00\x12Y\n\x1aset_heat_curve_delta_error\x18\r \x01(\x0e\x32\x33.device.heat_pump.command.v1.SetHeatCurveDeltaErrorH\x00\x12^\n\x1cset_telemetry_interval_error\x18\x0e \x01(\x0e\x32\x36.device.heat_pump.command.v1.SetTelemetryIntervalErrorH\x00\x42\x08\n\x06group0B\xbb\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x11\x43ommandErrorProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.command_error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\021CommandErrorProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_COMMANDERROR']._serialized_start=643
  _globals['_COMMANDERROR']._serialized_end=1556
# @@protoc_insertion_point(module_scope)