# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/ble/v1/system_check_state.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/ble/v1/system_check_state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from ...telemetry.v1.ccv.v1 import telemetry_data_pb2 as device_dot_heat__pump_dot_telemetry_dot_v1_dot_ccv_dot_v1_dot_telemetry__data__pb2
from ...state.v1 import state_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_state__pb2
from ...state.v1 import error_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_error__pb2
from ...config.v1.ccv.v1 import ccv_config_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_ccv_dot_v1_dot_ccv__config__pb2
from . import main_pump_flow_pb2 as device_dot_heat__pump_dot_ble_dot_v1_dot_main__pump__flow__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0device/heat_pump/ble/v1/system_check_state.proto\x12\x17\x64\x65vice.heat_pump.ble.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x39\x64\x65vice/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto\x1a%device/heat_pump/state/v1/state.proto\x1a%device/heat_pump/state/v1/error.proto\x1a\x32\x64\x65vice/heat_pump/config/v1/ccv/v1/ccv_config.proto\x1a,device/heat_pump/ble/v1/main_pump_flow.proto\"Z\n\x18GetSystemCheckStateError\x12>\n\x06\x65rrors\x18\x01 \x03(\x0e\x32..device.heat_pump.ble.v1.SystemCheckStateError\"\xa7\x01\n\x1bGetSystemCheckStateResponse\x12:\n\x05state\x18\x01 \x01(\x0b\x32).device.heat_pump.ble.v1.SystemCheckStateH\x00\x12\x42\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x31.device.heat_pump.ble.v1.GetSystemCheckStateErrorH\x00\x42\x08\n\x06group0\"\x83\x0c\n\x10SystemCheckState\x12\x30\n\x06\x65rrors\x18\x02 \x03(\x0b\x32 .device.heat_pump.state.v1.Error\x12I\n\rsensor_values\x18\x03 \x01(\x0b\x32\x32.device.heat_pump.telemetry.v1.ccv.v1.SensorValues\x12\x38\n\x0b\x61ir_purging\x18\x04 \x01(\x0b\x32#.device.heat_pump.ble.v1.AirPurging\x12S\n\x12\x65nergy_calculation\x18\n \x01(\x0b\x32\x37.device.heat_pump.telemetry.v1.ccv.v1.EnergyCalculation\x12!\n\x19system_check_mode_enabled\x18\x0b \x01(\x08\x12W\n\x14\x63\x61lculated_setpoints\x18\x0c \x01(\x0b\x32\x39.device.heat_pump.telemetry.v1.ccv.v1.CalculatedSetpoints\x12\\\n\x17\x63irculation_pump_status\x18\r \x01(\x0b\x32;.device.heat_pump.telemetry.v1.ccv.v1.CirculationPumpStatus\x12V\n\x14inline_heater_status\x18\x0e \x01(\x0b\x32\x38.device.heat_pump.telemetry.v1.ccv.v1.InlineHeaterStatus\x12G\n\x0cvalve_status\x18\x0f \x01(\x0b\x32\x31.device.heat_pump.telemetry.v1.ccv.v1.ValveStatus\x12\x43\n\nsmart_grid\x18\x10 \x01(\x0b\x32/.device.heat_pump.telemetry.v1.ccv.v1.SmartGrid\x12I\n\rmegmet_status\x18\x11 \x01(\x0b\x32\x32.device.heat_pump.telemetry.v1.ccv.v1.MegmetStatus\x12K\n\x0e\x65nergy_balance\x18\x12 \x01(\x0b\x32\x33.device.heat_pump.telemetry.v1.ccv.v1.EnergyBalance\x12G\n\x0cheating_mode\x18\x14 \x01(\x0b\x32\x31.device.heat_pump.telemetry.v1.ccv.v1.HeatingMode\x12\x1b\n\x13manual_mode_enabled\x18\x15 \x01(\x08\x12\x44\n\x10operating_status\x18\x16 \x01(\x0e\x32*.device.heat_pump.state.v1.OperatingStatus\x12H\n\x14main_pump_flow_state\x18\x17 \x01(\x0e\x32*.device.heat_pump.ble.v1.MainPumpFlowState\x12<\n\rforce_heating\x18\x18 \x01(\x0b\x32%.device.heat_pump.ble.v1.ForceHeating\x12\x37\n\x0cstarted_test\x18\x19 \x01(\x0e\x32!.device.heat_pump.ble.v1.TestType\x12\x44\n\x11\x65xternal_hardware\x18\x1a \x01(\x0b\x32).device.heat_pump.ble.v1.ExternalHardware\x12\x44\n\x11\x66low_optimization\x18\x1b \x01(\x0b\x32).device.heat_pump.ble.v1.FlowOptimization\x12\x45\n\x12inline_heater_test\x18\x1c \x01(\x0b\x32).device.heat_pump.ble.v1.InlineHeaterTest\x12K\n\x15\x63ompressor_speed_test\x18\x1d \x01(\x0b\x32,.device.heat_pump.ble.v1.CompressorSpeedTest\"\xe0\x05\n\x13\x43ompressorSpeedTest\x12\r\n\x05speed\x18\x01 \x01(\x05\x12?\n\x04mode\x18\x02 \x01(\x0e\x32\x31.device.heat_pump.ble.v1.CompressorSpeedTest.Mode\x12G\n\x08progress\x18\x03 \x01(\x0e\x32\x35.device.heat_pump.ble.v1.CompressorSpeedTest.Progress\x12*\n\x07runtime\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\ntotal_time\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n\nlast_error\x18\x06 \x01(\x0e\x32\x32.device.heat_pump.ble.v1.CompressorSpeedTest.Error\"\xe1\x01\n\x05\x45rror\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x00\x12\x16\n\x12\x45RROR_FLOW_TOO_LOW\x10\x01\x12\'\n#ERROR_DHW_TANK_TEMPERATURE_TOO_HIGH\x10\x02\x12*\n&ERROR_BUFFER_TANK_TEMPERATURE_TOO_HIGH\x10\x03\x12&\n\"ERROR_PRESSURE_DIFFERENCE_TOO_HIGH\x10\x04\x12\x13\n\x0f\x45RROR_TIMED_OUT\x10\x05\x12\x17\n\x13\x45RROR_TEST_CANCELED\x10\x06\"g\n\x08Progress\x12\x18\n\x14PROGRESS_UNSPECIFIED\x10\x00\x12\x14\n\x10PROGRESS_STOPPED\x10\x01\x12\x15\n\x11PROGRESS_STARTING\x10\x02\x12\x14\n\x10PROGRESS_RUNNING\x10\x03\"@\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x10\n\x0cMODE_COOLING\x10\x01\x12\x10\n\x0cMODE_HEATING\x10\x02\"\xcf\x04\n\x10InlineHeaterTest\x12\x44\n\x08progress\x18\x01 \x01(\x0e\x32\x32.device.heat_pump.ble.v1.InlineHeaterTest.Progress\x12\x32\n\x0ftotal_test_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07runtime\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12I\n\x0btested_step\x18\x04 \x01(\x0e\x32\x34.device.heat_pump.ble.v1.InlineHeaterTest.TestedStep\"q\n\nTestedStep\x12\x1b\n\x17TESTED_STEP_UNSPECIFIED\x10\x00\x12\x16\n\x12TESTED_STEP_STEP_1\x10\x01\x12\x16\n\x12TESTED_STEP_STEP_2\x10\x02\x12\x16\n\x12TESTED_STEP_STEP_3\x10\x03\"\xd6\x01\n\x08Progress\x12\x18\n\x14PROGRESS_UNSPECIFIED\x10\x00\x12\x17\n\x13PROGRESS_FLOW_CHECK\x10\x01\x12\x14\n\x10PROGRESS_HEATING\x10\x02\x12\x11\n\rPROGRESS_DONE\x10\x03\x12\x1e\n\x1aPROGRESS_FAILED_FLOW_CHECK\x10\x04\x12/\n+PROGRESS_FAILED_CONTROL_BOARD_COMMUNICATION\x10\x05\x12\x1d\n\x19PROGRESS_INVALID_ARGUMENT\x10\x06\"y\n\x10\x46lowOptimization\x12\x16\n\x0emin_pump_speed\x18\x01 \x01(\r\x12M\n\x11outdoor_unit_size\x18\x02 \x01(\x0e\x32\x32.device.heat_pump.config.v1.ccv.v1.OutdoorUnitSize\"R\n\x0c\x46orceHeating\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x31\n\x0eremaining_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x93\x01\n\x10\x45xternalHardware\x12\n\n\x02p1\x18\x01 \x01(\x08\x12\n\n\x02p2\x18\x02 \x01(\x08\x12\x0b\n\x03mv1\x18\x03 \x01(\x08\x12\x0b\n\x03mv2\x18\x04 \x01(\x08\x12M\n\x14inline_heater_config\x18\x05 \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.InlineHeater\"W\n\nAirPurging\x12\x10\n\x08progress\x18\x01 \x01(\r\x12\x37\n\x05state\x18\x02 \x01(\x0e\x32(.device.heat_pump.ble.v1.AirPurgingState*\xc8\x06\n\x15SystemCheckStateError\x12(\n$SYSTEM_CHECK_STATE_ERROR_UNSPECIFIED\x10\x00\x12#\n\x1fSYSTEM_CHECK_STATE_ERROR_ERRORS\x10\x01\x12*\n&SYSTEM_CHECK_STATE_ERROR_SENSOR_VALUES\x10\x02\x12(\n$SYSTEM_CHECK_STATE_ERROR_AIR_PURGING\x10\x03\x12-\n)SYSTEM_CHECK_STATE_ERROR_FLOW_METER_VALUE\x10\x04\x12)\n%SYSTEM_CHECK_STATE_ERROR_AMBIENT_TEMP\x10\x05\x12-\n)SYSTEM_CHECK_STATE_ERROR_INLET_WATER_TEMP\x10\x06\x12.\n*SYSTEM_CHECK_STATE_ERROR_OUTLET_WATER_TEMP\x10\x07\x12,\n(SYSTEM_CHECK_STATE_ERROR_INNER_COIL_TEMP\x10\x08\x12/\n+SYSTEM_CHECK_STATE_ERROR_ENERGY_CALCULATION\x10\t\x12;\n7SYSTEM_CHECK_STATE_ERROR_COLLECTION_ALREADY_IN_PROGRESS\x10\n\x12%\n!SYSTEM_CHECK_STATE_ERROR_INTERNAL\x10\x0b\x12\x31\n-SYSTEM_CHECK_STATE_ERROR_CALCULATED_SETPOINTS\x10\x0c\x12(\n$SYSTEM_CHECK_STATE_ERROR_PUMP_STATUS\x10\r\x12\x31\n-SYSTEM_CHECK_STATE_ERROR_INLINE_HEATER_STATUS\x10\x0e\x12)\n%SYSTEM_CHECK_STATE_ERROR_VALVE_STATUS\x10\x0f\x12\'\n#SYSTEM_CHECK_STATE_ERROR_SMART_GRID\x10\x10\x12*\n&SYSTEM_CHECK_STATE_ERROR_MEGMET_STATUS\x10\x11*\x92\x01\n\x0f\x41irPurgingState\x12!\n\x1d\x41IR_PURGING_STATE_UNSPECIFIED\x10\x00\x12!\n\x1d\x41IR_PURGING_STATE_NOT_STARTED\x10\x01\x12\x1d\n\x19\x41IR_PURGING_STATE_STARTED\x10\x02\x12\x1a\n\x16\x41IR_PURGING_STATE_DONE\x10\x03*\xbf\x02\n\x08TestType\x12\x19\n\x15TEST_TYPE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTEST_TYPE_AIR_PURGING_HEAT\x10\x01\x12\x17\n\x13TEST_TYPE_HEAT_FLOW\x10\x02\x12\x1d\n\x19TEST_TYPE_AIR_PURGING_DHW\x10\x03\x12\x16\n\x12TEST_TYPE_DHW_FLOW\x10\x04\x12 \n\x1cTEST_TYPE_MANUAL_INTERACTION\x10\x05\x12$\n TEST_TYPE_HEAT_FLOW_OPTIMIZATION\x10\x06\x12#\n\x1fTEST_TYPE_DHW_FLOW_OPTIMIZATION\x10\x07\x12\x1b\n\x17TEST_TYPE_INLINE_HEATER\x10\x08\x12\x1e\n\x1aTEST_TYPE_COMPRESSOR_SPEED\x10\tB\xab\x01\n\x17\x64\x65vice.heat_pump.ble.v1B\x15SystemCheckStateProtoP\x01\xa2\x02\x03\x44HB\xaa\x02\x16\x44\x65vice.HeatPump.Ble.V1\xca\x02\x16\x44\x65vice\\HeatPump\\Ble\\V1\xe2\x02\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\xea\x02\x19\x44\x65vice::HeatPump::Ble::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.ble.v1.system_check_state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027device.heat_pump.ble.v1B\025SystemCheckStateProtoP\001\242\002\003DHB\252\002\026Device.HeatPump.Ble.V1\312\002\026Device\\HeatPump\\Ble\\V1\342\002\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\352\002\031Device::HeatPump::Ble::V1'
  _globals['_SYSTEMCHECKSTATEERROR']._serialized_start=3928
  _globals['_SYSTEMCHECKSTATEERROR']._serialized_end=4768
  _globals['_AIRPURGINGSTATE']._serialized_start=4771
  _globals['_AIRPURGINGSTATE']._serialized_end=4917
  _globals['_TESTTYPE']._serialized_start=4920
  _globals['_TESTTYPE']._serialized_end=5239
  _globals['_GETSYSTEMCHECKSTATEERROR']._serialized_start=344
  _globals['_GETSYSTEMCHECKSTATEERROR']._serialized_end=434
  _globals['_GETSYSTEMCHECKSTATERESPONSE']._serialized_start=437
  _globals['_GETSYSTEMCHECKSTATERESPONSE']._serialized_end=604
  _globals['_SYSTEMCHECKSTATE']._serialized_start=607
  _globals['_SYSTEMCHECKSTATE']._serialized_end=2146
  _globals['_COMPRESSORSPEEDTEST']._serialized_start=2149
  _globals['_COMPRESSORSPEEDTEST']._serialized_end=2885
  _globals['_COMPRESSORSPEEDTEST_ERROR']._serialized_start=2489
  _globals['_COMPRESSORSPEEDTEST_ERROR']._serialized_end=2714
  _globals['_COMPRESSORSPEEDTEST_PROGRESS']._serialized_start=2716
  _globals['_COMPRESSORSPEEDTEST_PROGRESS']._serialized_end=2819
  _globals['_COMPRESSORSPEEDTEST_MODE']._serialized_start=2821
  _globals['_COMPRESSORSPEEDTEST_MODE']._serialized_end=2885
  _globals['_INLINEHEATERTEST']._serialized_start=2888
  _globals['_INLINEHEATERTEST']._serialized_end=3479
  _globals['_INLINEHEATERTEST_TESTEDSTEP']._serialized_start=3149
  _globals['_INLINEHEATERTEST_TESTEDSTEP']._serialized_end=3262
  _globals['_INLINEHEATERTEST_PROGRESS']._serialized_start=3265
  _globals['_INLINEHEATERTEST_PROGRESS']._serialized_end=3479
  _globals['_FLOWOPTIMIZATION']._serialized_start=3481
  _globals['_FLOWOPTIMIZATION']._serialized_end=3602
  _globals['_FORCEHEATING']._serialized_start=3604
  _globals['_FORCEHEATING']._serialized_end=3686
  _globals['_EXTERNALHARDWARE']._serialized_start=3689
  _globals['_EXTERNALHARDWARE']._serialized_end=3836
  _globals['_AIRPURGING']._serialized_start=3838
  _globals['_AIRPURGING']._serialized_end=3925
# @@protoc_insertion_point(module_scope)