# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/cloud/v1/service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/cloud/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....util.v2 import market_pb2 as util_dot_v2_dot_market__pb2
from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from .....util.v1 import type_of_day_pb2 as util_dot_v1_dot_type__of__day__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...command.v1 import command_progress_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__progress__pb2
from ...command.v1 import command_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'device/heat_pump/cloud/v1/service.proto\x12\x19\x64\x65vice.heat_pump.cloud.v1\x1a\x14util/v2/market.proto\x1a\x12util/v1/uuid.proto\x1a\x19util/v1/type_of_day.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32\x64\x65vice/heat_pump/command/v1/command_progress.proto\x1a)device/heat_pump/command/v1/command.proto\"\"\n DeleteLegionellaScheduleResponse\"F\n\x1f\x44\x65leteLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"w\n\x1dGetLegionellaScheduleResponse\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x31\n\rnext_run_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\x1cGetLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"\x1f\n\x1dSetLegionellaScheduleResponse\"\x97\x01\n\x1cSetLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x31\n\rnext_run_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x06market\x18\x03 \x01(\x0e\x32\x0f.util.v2.Market\"\x1b\n\x19\x44\x65leteDhwScheduleResponse\"?\n\x18\x44\x65leteDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"V\n\x16GetDhwScheduleResponse\x12<\n\x07\x65ntries\x18\x01 \x03(\x0b\x32+.device.heat_pump.cloud.v1.DhwScheduleEntry\"<\n\x15GetDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"v\n\x10\x44hwScheduleEntry\x12\x12\n\nstart_hour\x18\x01 \x01(\r\x12\x10\n\x08\x65nd_hour\x18\x02 \x01(\r\x12\'\n\x0btype_of_day\x18\x03 \x01(\x0e\x32\x12.util.v1.TypeOfDay\x12\x13\n\x0btemperature\x18\x04 \x01(\r\"\x18\n\x16SetDhwScheduleResponse\"\x9b\x01\n\x15SetDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12<\n\x07\x65ntries\x18\x02 \x03(\x0b\x32+.device.heat_pump.cloud.v1.DhwScheduleEntry\x12\x1f\n\x06market\x18\x03 \x01(\x0e\x32\x0f.util.v2.Market\"!\n\x1f\x44\x65leteScheduledAwayModeResponse\"E\n\x1e\x44\x65leteScheduledAwayModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"i\n\x1cGetScheduledAwayModeResponse\x12I\n\x13scheduled_away_mode\x18\x01 \x01(\x0b\x32,.device.heat_pump.cloud.v1.ScheduledAwayMode\"B\n\x1bGetScheduledAwayModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"I\n\x18ScheduleAwayModeResponse\x12-\n\x16scheduled_away_mode_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"d\n\x17ScheduleAwayModeRequest\x12I\n\x13scheduled_away_mode\x18\x01 \x01(\x0b\x32,.device.heat_pump.cloud.v1.ScheduledAwayMode\"\xa4\x01\n\x11ScheduledAwayMode\x12#\n\x0cheat_pump_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\"g\n\x1dStreamCommandProgressResponse\x12\x46\n\x10\x63ommand_progress\x18\x01 \x01(\x0b\x32,.device.heat_pump.command.v1.CommandProgress\"A\n\x1cStreamCommandProgressRequest\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"8\n\x13SendCommandResponse\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"p\n\x12SendCommandRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x35\n\x07\x63ommand\x18\x02 \x01(\x0b\x32$.device.heat_pump.command.v1.Command2\xcb\x0b\n\x14HeatPumpCloudService\x12~\n\x11\x44\x65leteDhwSchedule\x12\x33.device.heat_pump.cloud.v1.DeleteDhwScheduleRequest\x1a\x34.device.heat_pump.cloud.v1.DeleteDhwScheduleResponse\x12u\n\x0eGetDhwSchedule\x12\x30.device.heat_pump.cloud.v1.GetDhwScheduleRequest\x1a\x31.device.heat_pump.cloud.v1.GetDhwScheduleResponse\x12\x87\x01\n\x14GetScheduledAwayMode\x12\x36.device.heat_pump.cloud.v1.GetScheduledAwayModeRequest\x1a\x37.device.heat_pump.cloud.v1.GetScheduledAwayModeResponse\x12\x90\x01\n\x17\x44\x65leteScheduledAwayMode\x12\x39.device.heat_pump.cloud.v1.DeleteScheduledAwayModeRequest\x1a:.device.heat_pump.cloud.v1.DeleteScheduledAwayModeResponse\x12{\n\x10ScheduleAwayMode\x12\x32.device.heat_pump.cloud.v1.ScheduleAwayModeRequest\x1a\x33.device.heat_pump.cloud.v1.ScheduleAwayModeResponse\x12u\n\x0eSetDhwSchedule\x12\x30.device.heat_pump.cloud.v1.SetDhwScheduleRequest\x1a\x31.device.heat_pump.cloud.v1.SetDhwScheduleResponse\x12\x8a\x01\n\x15GetLegionellaSchedule\x12\x37.device.heat_pump.cloud.v1.GetLegionellaScheduleRequest\x1a\x38.device.heat_pump.cloud.v1.GetLegionellaScheduleResponse\x12\x8a\x01\n\x15SetLegionellaSchedule\x12\x37.device.heat_pump.cloud.v1.SetLegionellaScheduleRequest\x1a\x38.device.heat_pump.cloud.v1.SetLegionellaScheduleResponse\x12\x93\x01\n\x18\x44\x65leteLegionellaSchedule\x12:.device.heat_pump.cloud.v1.DeleteLegionellaScheduleRequest\x1a;.device.heat_pump.cloud.v1.DeleteLegionellaScheduleResponse\x12\x8c\x01\n\x15StreamCommandProgress\x12\x37.device.heat_pump.cloud.v1.StreamCommandProgressRequest\x1a\x38.device.heat_pump.cloud.v1.StreamCommandProgressResponse0\x01\x12l\n\x0bSendCommand\x12-.device.heat_pump.cloud.v1.SendCommandRequest\x1a..device.heat_pump.cloud.v1.SendCommandResponseB\xac\x01\n\x19\x64\x65vice.heat_pump.cloud.v1B\x0cServiceProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x18\x44\x65vice.HeatPump.Cloud.V1\xca\x02\x18\x44\x65vice\\HeatPump\\Cloud\\V1\xe2\x02$Device\\HeatPump\\Cloud\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::Cloud::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.cloud.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031device.heat_pump.cloud.v1B\014ServiceProtoP\001\242\002\003DHC\252\002\030Device.HeatPump.Cloud.V1\312\002\030Device\\HeatPump\\Cloud\\V1\342\002$Device\\HeatPump\\Cloud\\V1\\GPBMetadata\352\002\033Device::HeatPump::Cloud::V1'
  _globals['_DELETELEGIONELLASCHEDULERESPONSE']._serialized_start=267
  _globals['_DELETELEGIONELLASCHEDULERESPONSE']._serialized_end=301
  _globals['_DELETELEGIONELLASCHEDULEREQUEST']._serialized_start=303
  _globals['_DELETELEGIONELLASCHEDULEREQUEST']._serialized_end=373
  _globals['_GETLEGIONELLASCHEDULERESPONSE']._serialized_start=375
  _globals['_GETLEGIONELLASCHEDULERESPONSE']._serialized_end=494
  _globals['_GETLEGIONELLASCHEDULEREQUEST']._serialized_start=496
  _globals['_GETLEGIONELLASCHEDULEREQUEST']._serialized_end=563
  _globals['_SETLEGIONELLASCHEDULERESPONSE']._serialized_start=565
  _globals['_SETLEGIONELLASCHEDULERESPONSE']._serialized_end=596
  _globals['_SETLEGIONELLASCHEDULEREQUEST']._serialized_start=599
  _globals['_SETLEGIONELLASCHEDULEREQUEST']._serialized_end=750
  _globals['_DELETEDHWSCHEDULERESPONSE']._serialized_start=752
  _globals['_DELETEDHWSCHEDULERESPONSE']._serialized_end=779
  _globals['_DELETEDHWSCHEDULEREQUEST']._serialized_start=781
  _globals['_DELETEDHWSCHEDULEREQUEST']._serialized_end=844
  _globals['_GETDHWSCHEDULERESPONSE']._serialized_start=846
  _globals['_GETDHWSCHEDULERESPONSE']._serialized_end=932
  _globals['_GETDHWSCHEDULEREQUEST']._serialized_start=934
  _globals['_GETDHWSCHEDULEREQUEST']._serialized_end=994
  _globals['_DHWSCHEDULEENTRY']._serialized_start=996
  _globals['_DHWSCHEDULEENTRY']._serialized_end=1114
  _globals['_SETDHWSCHEDULERESPONSE']._serialized_start=1116
  _globals['_SETDHWSCHEDULERESPONSE']._serialized_end=1140
  _globals['_SETDHWSCHEDULEREQUEST']._serialized_start=1143
  _globals['_SETDHWSCHEDULEREQUEST']._serialized_end=1298
  _globals['_DELETESCHEDULEDAWAYMODERESPONSE']._serialized_start=1300
  _globals['_DELETESCHEDULEDAWAYMODERESPONSE']._serialized_end=1333
  _globals['_DELETESCHEDULEDAWAYMODEREQUEST']._serialized_start=1335
  _globals['_DELETESCHEDULEDAWAYMODEREQUEST']._serialized_end=1404
  _globals['_GETSCHEDULEDAWAYMODERESPONSE']._serialized_start=1406
  _globals['_GETSCHEDULEDAWAYMODERESPONSE']._serialized_end=1511
  _globals['_GETSCHEDULEDAWAYMODEREQUEST']._serialized_start=1513
  _globals['_GETSCHEDULEDAWAYMODEREQUEST']._serialized_end=1579
  _globals['_SCHEDULEAWAYMODERESPONSE']._serialized_start=1581
  _globals['_SCHEDULEAWAYMODERESPONSE']._serialized_end=1654
  _globals['_SCHEDULEAWAYMODEREQUEST']._serialized_start=1656
  _globals['_SCHEDULEAWAYMODEREQUEST']._serialized_end=1756
  _globals['_SCHEDULEDAWAYMODE']._serialized_start=1759
  _globals['_SCHEDULEDAWAYMODE']._serialized_end=1923
  _globals['_STREAMCOMMANDPROGRESSRESPONSE']._serialized_start=1925
  _globals['_STREAMCOMMANDPROGRESSRESPONSE']._serialized_end=2028
  _globals['_STREAMCOMMANDPROGRESSREQUEST']._serialized_start=2030
  _globals['_STREAMCOMMANDPROGRESSREQUEST']._serialized_end=2095
  _globals['_SENDCOMMANDRESPONSE']._serialized_start=2097
  _globals['_SENDCOMMANDRESPONSE']._serialized_end=2153
  _globals['_SENDCOMMANDREQUEST']._serialized_start=2155
  _globals['_SENDCOMMANDREQUEST']._serialized_end=2267
  _globals['_HEATPUMPCLOUDSERVICE']._serialized_start=2270
  _globals['_HEATPUMPCLOUDSERVICE']._serialized_end=3753
# @@protoc_insertion_point(module_scope)