# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: util/v2/locale.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'util/v2/locale.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14util/v2/locale.proto\x12\x07util.v2*M\n\x06Locale\x12\x16\n\x12LOCALE_UNSPECIFIED\x10\x00\x12\r\n\tLOCALE_IT\x10\x01\x12\r\n\tLOCALE_DE\x10\x02\x12\r\n\tLOCALE_EN\x10\x03\x42S\n\x07util.v2B\x0bLocaleProtoP\x01\xa2\x02\x03UXX\xaa\x02\x07Util.V2\xca\x02\x07Util\\V2\xe2\x02\x13Util\\V2\\GPBMetadata\xea\x02\x08Util::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'util.v2.locale_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\007util.v2B\013LocaleProtoP\001\242\002\003UXX\252\002\007Util.V2\312\002\007Util\\V2\342\002\023Util\\V2\\GPBMetadata\352\002\010Util::V2'
  _globals['_LOCALE']._serialized_start=33
  _globals['_LOCALE']._serialized_end=110
# @@protoc_insertion_point(module_scope)