# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/power/peripheral/photovoltaics/v1/config.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/power/peripheral/photovoltaics/v1/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5device/power/peripheral/photovoltaics/v1/config.proto\x12(device.power.peripheral.photovoltaics.v1\"#\n\x13PhotovoltaicsConfig\x12\x0c\n\x04mode\x18\x01 \x01(\x08\x42\xfb\x01\n(device.power.peripheral.photovoltaics.v1B\x0b\x43onfigProtoP\x01\xa2\x02\x03PPP\xaa\x02(Device.Power.Peripheral.Photovoltaics.V1\xca\x02(Device\\Power\\Peripheral\\Photovoltaics\\V1\xe2\x02\x34\x44\x65vice\\Power\\Peripheral\\Photovoltaics\\V1\\GPBMetadata\xea\x02,Device::Power::Peripheral::Photovoltaics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.power.peripheral.photovoltaics.v1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(device.power.peripheral.photovoltaics.v1B\013ConfigProtoP\001\242\002\003PPP\252\002(Device.Power.Peripheral.Photovoltaics.V1\312\002(Device\\Power\\Peripheral\\Photovoltaics\\V1\342\0024Device\\Power\\Peripheral\\Photovoltaics\\V1\\GPBMetadata\352\002,Device::Power::Peripheral::Photovoltaics::V1'
  _globals['_PHOTOVOLTAICSCONFIG']._serialized_start=99
  _globals['_PHOTOVOLTAICSCONFIG']._serialized_end=134
# @@protoc_insertion_point(module_scope)