# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/ble/v1/chunked_message.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/ble/v1/chunked_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-device/heat_pump/ble/v1/chunked_message.proto\x12\x17\x64\x65vice.heat_pump.ble.v1\x1a\x12util/v1/uuid.proto\"n\n\x0e\x43hunkedMessage\x12!\n\nmessage_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x13\n\x0b\x62yte_offset\x18\x02 \x01(\x04\x12\x13\n\x0btotal_bytes\x18\x03 \x01(\x04\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\x42\xa9\x01\n\x17\x64\x65vice.heat_pump.ble.v1B\x13\x43hunkedMessageProtoP\x01\xa2\x02\x03\x44HB\xaa\x02\x16\x44\x65vice.HeatPump.Ble.V1\xca\x02\x16\x44\x65vice\\HeatPump\\Ble\\V1\xe2\x02\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\xea\x02\x19\x44\x65vice::HeatPump::Ble::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.ble.v1.chunked_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027device.heat_pump.ble.v1B\023ChunkedMessageProtoP\001\242\002\003DHB\252\002\026Device.HeatPump.Ble.V1\312\002\026Device\\HeatPump\\Ble\\V1\342\002\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\352\002\031Device::HeatPump::Ble::V1'
  _globals['_CHUNKEDMESSAGE']._serialized_start=94
  _globals['_CHUNKEDMESSAGE']._serialized_end=204
# @@protoc_insertion_point(module_scope)