# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/missing_field_error.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/missing_field_error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5device/heat_pump/command/v1/missing_field_error.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\"\x0f\n\rZoneSetpoints\"\x0b\n\tTimestamp\"\xb2\x02\n\x11MissingFieldError\x12G\n\x10heat_curve_point\x18\x01 \x01(\x0e\x32+.device.heat_pump.command.v1.HeatCurvePointH\x00\x12;\n\ttimestamp\x18\x02 \x01(\x0b\x32&.device.heat_pump.command.v1.TimestampH\x00\x12\x44\n\x0ezone_setpoints\x18\x03 \x01(\x0b\x32*.device.heat_pump.command.v1.ZoneSetpointsH\x00\x12G\n\x10\x63ool_curve_point\x18\x04 \x01(\x0e\x32+.device.heat_pump.command.v1.CoolCurvePointH\x00\x42\x08\n\x06group0*}\n\x0e\x43oolCurvePoint\x12 \n\x1c\x43OOL_CURVE_POINT_UNSPECIFIED\x10\x00\x12\x17\n\x13\x43OOL_CURVE_POINT_P1\x10\x01\x12\x17\n\x13\x43OOL_CURVE_POINT_P2\x10\x02\x12\x17\n\x13\x43OOL_CURVE_POINT_P3\x10\x03*\xaf\x01\n\x0eHeatCurvePoint\x12 \n\x1cHEAT_CURVE_POINT_UNSPECIFIED\x10\x00\x12\x17\n\x13HEAT_CURVE_POINT_P1\x10\x01\x12\x17\n\x13HEAT_CURVE_POINT_P2\x10\x02\x12\x17\n\x13HEAT_CURVE_POINT_P3\x10\x03\x12\x17\n\x13HEAT_CURVE_POINT_P4\x10\x04\x12\x17\n\x13HEAT_CURVE_POINT_P5\x10\x05\x42\xc0\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x16MissingFieldErrorProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.missing_field_error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\026MissingFieldErrorProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_COOLCURVEPOINT']._serialized_start=425
  _globals['_COOLCURVEPOINT']._serialized_end=550
  _globals['_HEATCURVEPOINT']._serialized_start=553
  _globals['_HEATCURVEPOINT']._serialized_end=728
  _globals['_ZONESETPOINTS']._serialized_start=86
  _globals['_ZONESETPOINTS']._serialized_end=101
  _globals['_TIMESTAMP']._serialized_start=103
  _globals['_TIMESTAMP']._serialized_end=114
  _globals['_MISSINGFIELDERROR']._serialized_start=117
  _globals['_MISSINGFIELDERROR']._serialized_end=423
# @@protoc_insertion_point(module_scope)