# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/config/v1/ccv/v1/ccv_config.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/config/v1/ccv/v1/ccv_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import heat_curve_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_ccv_dot_v1_dot_heat__curve__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2device/heat_pump/config/v1/ccv/v1/ccv_config.proto\x12!device.heat_pump.config.v1.ccv.v1\x1a\x32\x64\x65vice/heat_pump/config/v1/ccv/v1/heat_curve.proto\"\xa2\x08\n\tCcvConfig\x12H\n\x0esensor_sources\x18\x01 \x01(\x0b\x32\x30.device.heat_pump.config.v1.ccv.v1.SensorSources\x12R\n\x13\x63ompressor_settings\x18\x02 \x01(\x0b\x32\x35.device.heat_pump.config.v1.ccv.v1.CompressorSettings\x12H\n\x0eheating_system\x18\x07 \x01(\x0b\x32\x30.device.heat_pump.config.v1.ccv.v1.HeatingSystem\x12@\n\ndhw_system\x18\x08 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.DhwSystem\x12>\n\taway_mode\x18\t \x01(\x0b\x32+.device.heat_pump.config.v1.ccv.v1.AwayMode\x12J\n\x0fheating_cooling\x18\n \x01(\x0b\x32\x31.device.heat_pump.config.v1.ccv.v1.HeatingCooling\x12M\n\x11outdoor_unit_size\x18\r \x01(\x0e\x32\x32.device.heat_pump.config.v1.ccv.v1.OutdoorUnitSize\x12Q\n\x13pump_speed_settings\x18\x0e \x01(\x0b\x32\x34.device.heat_pump.config.v1.ccv.v1.PumpSpeedSettings\x12L\n\x10\x61larm_thresholds\x18\x0f \x01(\x0b\x32\x32.device.heat_pump.config.v1.ccv.v1.AlarmThresholds\x12N\n\x11\x65lectricity_meter\x18\x10 \x01(\x0b\x32\x33.device.heat_pump.config.v1.ccv.v1.ElectricityMeter\x12\x46\n\rinline_heater\x18\x11 \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.InlineHeater\x12@\n\nnight_mode\x18\x12 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.NightMode\x12\x42\n\x0b\x66low_meters\x18\x13 \x01(\x0b\x32-.device.heat_pump.config.v1.ccv.v1.FlowMeters\x12Q\n\x13\x65nergy_balance_kick\x18\x14 \x01(\x0b\x32\x34.device.heat_pump.config.v1.ccv.v1.EnergyBalanceKick\"k\n\x11\x45nergyBalanceKick\x12\x1a\n\x12time_between_kicks\x18\x01 \x01(\r\x12\x1b\n\x13kick_temperature_up\x18\x02 \x01(\x02\x12\x1d\n\x15kick_temperature_down\x18\x03 \x01(\x02\"\xc7\x03\n\nFlowMeters\x12P\n\x0bmeter1_type\x18\x01 \x01(\x0e\x32;.device.heat_pump.config.v1.ccv.v1.FlowMeters.FlowMeterType\x12P\n\x0bmeter2_type\x18\x02 \x01(\x0e\x32;.device.heat_pump.config.v1.ccv.v1.FlowMeters.FlowMeterType\"\x94\x02\n\rFlowMeterType\x12\x1f\n\x1b\x46LOW_METER_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1d\x46LOW_METER_TYPE_NOT_CONNECTED\x10\x01\x12$\n FLOW_METER_TYPE_HUBA_DN20_BRONZE\x10\x02\x12$\n FLOW_METER_TYPE_HUBA_DN25_BRONZE\x10\x03\x12%\n!FLOW_METER_TYPE_HUBA_DN20_PLASTIC\x10\x04\x12%\n!FLOW_METER_TYPE_HUBA_DN25_PLASTIC\x10\x05\x12%\n!FLOW_METER_TYPE_HUBA_DN10_PLASTIC\x10\x06\"\x1c\n\tNightMode\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\xa1\x03\n\x0cInlineHeater\x12P\n\x05step1\x18\x01 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\x12P\n\x05step2\x18\x02 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\x12P\n\x05step3\x18\x03 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\"\x9a\x01\n\x11InlineHeaterUsage\x12#\n\x1fINLINE_HEATER_USAGE_UNSPECIFIED\x10\x00\x12 \n\x1cINLINE_HEATER_USAGE_DISABLED\x10\x01\x12\x1e\n\x1aINLINE_HEATER_USAGE_BACKUP\x10\x02\x12\x1e\n\x1aINLINE_HEATER_USAGE_NORMAL\x10\x03\"\x90\x02\n\x10\x45lectricityMeter\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.device.heat_pump.config.v1.ccv.v1.ElectricityMeter.ElectricityMeterType\"\xa3\x01\n\x14\x45lectricityMeterType\x12&\n\"ELECTRICITY_METER_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45LECTRICITY_METER_TYPE_NONE\x10\x01\x12 \n\x1c\x45LECTRICITY_METER_TYPE_ET340\x10\x02\x12 \n\x1c\x45LECTRICITY_METER_TYPE_ET112\x10\x03\"f\n\x0f\x41larmThresholds\x12\x1b\n\x13\x66low_level1_low12kw\x18\x01 \x01(\x02\x12\x1a\n\x12\x66low_level1_low8kw\x18\x02 \x01(\x02\x12\x1a\n\x12\x66low_level1_low6kw\x18\x03 \x01(\x02\"x\n\x11PumpSpeedSettings\x12\x0f\n\x07heating\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ooling\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x65\x66rost\x18\x03 \x01(\x05\x12\x0f\n\x07minimum\x18\x04 \x01(\x05\x12\x12\n\nlegionella\x18\x05 \x01(\x05\x12\x0b\n\x03\x64hw\x18\x06 \x01(\x05\"\xe4\x03\n\x0eHeatingCooling\x12\x11\n\tnum_zones\x18\x01 \x01(\x05\x12\x32\n*ambient_temperature_to_enable_heating_mode\x18\x03 \x01(\x02\x12\x32\n*ambient_temperature_to_enable_cooling_mode\x18\x04 \x01(\x02\x12+\n#minimum_time_heating_cooling_switch\x18\x06 \x01(\x05\x12\x33\n+supply_temperature_too_high_alarm_temp_diff\x18\x07 \x01(\x02\x12/\n\'supply_temperature_too_high_alarm_delay\x18\x08 \x01(\x05\x12G\n\x0esettings_zone1\x18\t \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.ZoneSettings\x12G\n\x0esettings_zone2\x18\n \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.ZoneSettings\x12\x32\n*ambient_temperature_to_allow_inline_heater\x18\x0b \x01(\x02\"P\n\x08\x41wayMode\x12#\n\x1b\x64hw_tank_temperature_change\x18\x02 \x01(\x02\x12\x1f\n\x17room_temperature_change\x18\x03 \x01(\x02\"\xbf\x03\n\x0cZoneSettings\x12&\n\x1a\x64\x65precated_control_enabled\x18\x01 \x01(\x08\x42\x02\x18\x01\x12G\n\x07heating\x18\x03 \x01(\x0b\x32\x36.device.heat_pump.config.v1.ccv.v1.ZoneHeatingSettings\x12G\n\x07\x63ooling\x18\x04 \x01(\x0b\x32\x36.device.heat_pump.config.v1.ccv.v1.ZoneCoolingSettings\x12I\n\x11room_pi_regulator\x18\x05 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulator\x12`\n$deprecated_mixing_valve_pi_regulator\x18\x06 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulatorB\x02\x18\x01\x12H\n\x0cmixing_valve\x18\x07 \x01(\x0b\x32\x32.device.heat_pump.config.v1.ccv.v1.ZoneMixingValve\"\xd0\x01\n\x13ZoneCoolingSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rroom_setpoint\x18\x02 \x01(\x02\x12\x1f\n\x17minimum_supply_setpoint\x18\x03 \x01(\x02\x12\x1f\n\x17maximum_supply_setpoint\x18\x04 \x01(\x02\x12O\n\ncool_curve\x18\x05 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearCoolCurve\"\xd0\x01\n\x13ZoneHeatingSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rroom_setpoint\x18\x02 \x01(\x02\x12\x1f\n\x17minimum_supply_setpoint\x18\x03 \x01(\x02\x12\x1f\n\x17maximum_supply_setpoint\x18\x04 \x01(\x02\x12O\n\nheat_curve\x18\x05 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearHeatCurve\"\xdc\x01\n\x0fZoneMixingValve\x12\x1e\n\x16regulation_period_time\x18\x01 \x01(\x05\x12\x1f\n\x17\x65nd_to_end_running_time\x18\x02 \x01(\x05\x12)\n!minimum_relay_output_pulse_length\x18\x03 \x01(\x05\x12\x17\n\x0f\x63ontrol_enabled\x18\x04 \x01(\x08\x12\x44\n\x0cpi_regulator\x18\x05 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulator\"\x8b\x03\n\tDhwSystem\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0c\x64hw_setpoint\x18\x02 \x01(\x02\x12\x19\n\x11\x64hw_setpoint_diff\x18\x03 \x01(\x02\x12G\n\x05\x62oost\x18\x04 \x01(\x0b\x32\x38.device.heat_pump.config.v1.ccv.v1.DomesticHotWaterBoost\x12%\n\x1dtank_temperature_night_change\x18\x05 \x01(\x02\x12!\n\x19\x63ompressor_speed_dhw_mode\x18\x06 \x01(\x05\x12$\n\x1cmaximum_setpoint_temperature\x18\x07 \x01(\x02\x12/\n\'unacknowledged_alarm_temperature_change\x18\x08 \x01(\x02\x12R\n\x13legionella_settings\x18\t \x01(\x0b\x32\x35.device.heat_pump.config.v1.ccv.v1.LegionellaSettings\"\xab\x01\n\x12LegionellaSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1b\n\x13interval_time_start\x18\x02 \x01(\x05\x12\x1a\n\x12interval_time_stop\x18\x03 \x01(\x05\x12\x18\n\x10maximum_duration\x18\x04 \x01(\x05\x12\x1a\n\x12target_temperature\x18\x05 \x01(\x02\x12\x15\n\rinterval_days\x18\x06 \x01(\x05\"\xb2\x02\n\rHeatingSystem\x12\x14\n\x0cheating_time\x18\x01 \x01(\x05\x12\x10\n\x08\x64hw_time\x18\x02 \x01(\x05\x12\x41\n9minimum_inline_heater_cooling_time_before_compressor_stop\x18\x04 \x01(\x05\x12\x17\n\x0fheat_balance_a0\x18\x05 \x01(\x05\x12\x17\n\x0fheat_balance_a2\x18\x06 \x01(\x05\x12\x14\n\x0c\x63ooling_time\x18\x07 \x01(\x05\x12\x17\n\x0f\x63ool_balance_k0\x18\x08 \x01(\x05\x12U\n\x1d\x63ompressor_speed_pi_regulator\x18\t \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulator\"1\n\x0bPiRegulator\x12\x10\n\x08p_factor\x18\x01 \x01(\x02\x12\x10\n\x08i_factor\x18\x02 \x01(\x02\"d\n\x15\x44omesticHotWaterBoost\x12+\n\x1f\x64\x65precated_remaining_boost_time\x18\x01 \x01(\x05\x42\x02\x18\x01\x12\x1e\n\x16tank_temp_boost_change\x18\x02 \x01(\x02\"\x93\x05\n\x12\x43ompressorSettings\x12\"\n\x16\x64\x65precated_speed_level\x18\x01 \x01(\x05\x42\x02\x18\x01\x12#\n\x17\x64\x65precated_working_mode\x18\x02 \x01(\x05\x42\x02\x18\x01\x12&\n\x1eminimum_time_start_start_cycle\x18\x03 \x01(\x05\x12%\n\x1dminimum_time_stop_start_cycle\x18\x04 \x01(\x05\x12!\n\x19p0_compressor_prerun_time\x18\x05 \x01(\x05\x12\'\n\x1f\x64hw_diverting_valve_prerun_time\x18\x06 \x01(\x05\x12#\n\x1bp0_compressor_afterrun_time\x18\x07 \x01(\x05\x12%\n\x1d\x64iverting_valve_afterrun_time\x18\x08 \x01(\x05\x12 \n\x18p0_autostart_temperature\x18\t \x01(\x02\x12\"\n\x1amaximum_outlet_temperature\x18\n \x01(\x02\x12\"\n\x1aminimum_outlet_temperature\x18\x0b \x01(\x02\x12!\n\x19maximum_inlet_temperature\x18\x0c \x01(\x02\x12!\n\x19minimum_inlet_temperature\x18\r \x01(\x02\x12&\n\x1eminimum_inner_coil_temperature\x18\x0e \x01(\x02\x12,\n deprecated_compressor_limit_time\x18\x0f \x01(\x05\x42\x02\x18\x01\x12(\n compressor_inner_coil_block_time\x18\x10 \x01(\x05\x12\x1d\n\x15\x63ompressor_limit_time\x18\x11 \x01(\x02\"\x84\x04\n\rSensorSources\x12/\n\'outdoor_unit_ambient_temperature_source\x18\x01 \x01(\r\x12.\n&outdoor_unit_supply_temperature_source\x18\x02 \x01(\r\x12.\n&outdoor_unit_return_temperature_source\x18\x03 \x01(\r\x12\x32\n*outdoor_unit_inner_coil_temperature_source\x18\x04 \x01(\r\x12/\n\'indoor_unit_dhw_tank_temperature_source\x18\x05 \x01(\r\x12-\n%indoor_unit_supply_temperature_source\x18\x06 \x01(\r\x12\x33\n+indoor_unit_supply_temperature_zone1_source\x18\x07 \x01(\r\x12\x33\n+indoor_unit_supply_temperature_zone2_source\x18\x08 \x01(\r\x12\x31\n)indoor_unit_room_temperature_zone1_source\x18\t \x01(\r\x12\x31\n)indoor_unit_room_temperature_zone2_source\x18\n \x01(\r*\x95\x01\n\x0fOutdoorUnitSize\x12!\n\x1dOUTDOOR_UNIT_SIZE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aOUTDOOR_UNIT_SIZE_AIRA_6KW\x10\x01\x12\x1e\n\x1aOUTDOOR_UNIT_SIZE_AIRA_8KW\x10\x02\x12\x1f\n\x1bOUTDOOR_UNIT_SIZE_AIRA_12KW\x10\x03\x42\xd8\x01\n!device.heat_pump.config.v1.ccv.v1B\x0e\x43\x63vConfigProtoP\x01\xa2\x02\x03\x43VC\xaa\x02 Device.HeatPump.Config.V1.Ccv.V1\xca\x02 Device\\HeatPump\\Config\\V1\\Ccv\\V1\xe2\x02,Device\\HeatPump\\Config\\V1\\Ccv\\V1\\GPBMetadata\xea\x02%Device::HeatPump::Config::V1::Ccv::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.config.v1.ccv.v1.ccv_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!device.heat_pump.config.v1.ccv.v1B\016CcvConfigProtoP\001\242\002\003CVC\252\002 Device.HeatPump.Config.V1.Ccv.V1\312\002 Device\\HeatPump\\Config\\V1\\Ccv\\V1\342\002,Device\\HeatPump\\Config\\V1\\Ccv\\V1\\GPBMetadata\352\002%Device::HeatPump::Config::V1::Ccv::V1'
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_control_enabled']._loaded_options = None
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_control_enabled']._serialized_options = b'\030\001'
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_mixing_valve_pi_regulator']._loaded_options = None
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_mixing_valve_pi_regulator']._serialized_options = b'\030\001'
  _globals['_DOMESTICHOTWATERBOOST'].fields_by_name['deprecated_remaining_boost_time']._loaded_options = None
  _globals['_DOMESTICHOTWATERBOOST'].fields_by_name['deprecated_remaining_boost_time']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_speed_level']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_speed_level']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_working_mode']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_working_mode']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_compressor_limit_time']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_compressor_limit_time']._serialized_options = b'\030\001'
  _globals['_OUTDOORUNITSIZE']._serialized_start=6600
  _globals['_OUTDOORUNITSIZE']._serialized_end=6749
  _globals['_CCVCONFIG']._serialized_start=142
  _globals['_CCVCONFIG']._serialized_end=1200
  _globals['_ENERGYBALANCEKICK']._serialized_start=1202
  _globals['_ENERGYBALANCEKICK']._serialized_end=1309
  _globals['_FLOWMETERS']._serialized_start=1312
  _globals['_FLOWMETERS']._serialized_end=1767
  _globals['_FLOWMETERS_FLOWMETERTYPE']._serialized_start=1491
  _globals['_FLOWMETERS_FLOWMETERTYPE']._serialized_end=1767
  _globals['_NIGHTMODE']._serialized_start=1769
  _globals['_NIGHTMODE']._serialized_end=1797
  _globals['_INLINEHEATER']._serialized_start=1800
  _globals['_INLINEHEATER']._serialized_end=2217
  _globals['_INLINEHEATER_INLINEHEATERUSAGE']._serialized_start=2063
  _globals['_INLINEHEATER_INLINEHEATERUSAGE']._serialized_end=2217
  _globals['_ELECTRICITYMETER']._serialized_start=2220
  _globals['_ELECTRICITYMETER']._serialized_end=2492
  _globals['_ELECTRICITYMETER_ELECTRICITYMETERTYPE']._serialized_start=2329
  _globals['_ELECTRICITYMETER_ELECTRICITYMETERTYPE']._serialized_end=2492
  _globals['_ALARMTHRESHOLDS']._serialized_start=2494
  _globals['_ALARMTHRESHOLDS']._serialized_end=2596
  _globals['_PUMPSPEEDSETTINGS']._serialized_start=2598
  _globals['_PUMPSPEEDSETTINGS']._serialized_end=2718
  _globals['_HEATINGCOOLING']._serialized_start=2721
  _globals['_HEATINGCOOLING']._serialized_end=3205
  _globals['_AWAYMODE']._serialized_start=3207
  _globals['_AWAYMODE']._serialized_end=3287
  _globals['_ZONESETTINGS']._serialized_start=3290
  _globals['_ZONESETTINGS']._serialized_end=3737
  _globals['_ZONECOOLINGSETTINGS']._serialized_start=3740
  _globals['_ZONECOOLINGSETTINGS']._serialized_end=3948
  _globals['_ZONEHEATINGSETTINGS']._serialized_start=3951
  _globals['_ZONEHEATINGSETTINGS']._serialized_end=4159
  _globals['_ZONEMIXINGVALVE']._serialized_start=4162
  _globals['_ZONEMIXINGVALVE']._serialized_end=4382
  _globals['_DHWSYSTEM']._serialized_start=4385
  _globals['_DHWSYSTEM']._serialized_end=4780
  _globals['_LEGIONELLASETTINGS']._serialized_start=4783
  _globals['_LEGIONELLASETTINGS']._serialized_end=4954
  _globals['_HEATINGSYSTEM']._serialized_start=4957
  _globals['_HEATINGSYSTEM']._serialized_end=5263
  _globals['_PIREGULATOR']._serialized_start=5265
  _globals['_PIREGULATOR']._serialized_end=5314
  _globals['_DOMESTICHOTWATERBOOST']._serialized_start=5316
  _globals['_DOMESTICHOTWATERBOOST']._serialized_end=5416
  _globals['_COMPRESSORSETTINGS']._serialized_start=5419
  _globals['_COMPRESSORSETTINGS']._serialized_end=6078
  _globals['_SENSORSOURCES']._serialized_start=6081
  _globals['_SENSORSOURCES']._serialized_end=6597
# @@protoc_insertion_point(module_scope)