# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/modbus.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/modbus.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(device/heat_pump/command/v1/modbus.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\"O\n\x0eModbusResponse\x12=\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32/.device.heat_pump.command.v1.ModbusRegisterData\"\xa3\x01\n\x12ModbusRegisterData\x12\x0e\n\x04\x63oil\x18\x01 \x01(\x08H\x00\x12\x0e\n\x04\x62yte\x18\x02 \x01(\rH\x00\x12\x15\n\x0bsigned_byte\x18\x03 \x01(\x11H\x00\x12\x0e\n\x04word\x18\x04 \x01(\rH\x00\x12\x15\n\x0bsigned_word\x18\x05 \x01(\x11H\x00\x12\x0e\n\x04long\x18\x06 \x01(\rH\x00\x12\x15\n\x0bsigned_long\x18\x07 \x01(\x11H\x00\x42\x08\n\x06group0\"\x9b\x02\n\rModbusRequest\x12\x35\n\x04unit\x18\x01 \x01(\x0e\x32\'.device.heat_pump.command.v1.ModbusUnit\x12=\n\x08\x66unction\x18\x02 \x01(\x0e\x32+.device.heat_pump.command.v1.ModbusFunction\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\r\x12=\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32/.device.heat_pump.command.v1.ModbusRegisterData\x12\x44\n\x0breturn_type\x18\x05 \x01(\x0e\x32/.device.heat_pump.command.v1.ModbusRegisterType*\xa8\x02\n\x12ModbusRegisterType\x12$\n MODBUS_REGISTER_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19MODBUS_REGISTER_TYPE_COIL\x10\x01\x12\x1d\n\x19MODBUS_REGISTER_TYPE_BYTE\x10\x02\x12$\n MODBUS_REGISTER_TYPE_SIGNED_BYTE\x10\x03\x12\x1d\n\x19MODBUS_REGISTER_TYPE_WORD\x10\x04\x12$\n MODBUS_REGISTER_TYPE_SIGNED_WORD\x10\x05\x12\x1d\n\x19MODBUS_REGISTER_TYPE_LONG\x10\x06\x12$\n MODBUS_REGISTER_TYPE_SIGNED_LONG\x10\x07*\xd5\x01\n\x0eModbusFunction\x12\x1f\n\x1bMODBUS_FUNCTION_UNSPECIFIED\x10\x00\x12\x1d\n\x19MODBUS_FUNCTION_READ_COIL\x10\x01\x12 \n\x1cMODBUS_FUNCTION_READ_HOLDING\x10\x03\x12\x1e\n\x1aMODBUS_FUNCTION_READ_INPUT\x10\x04\x12\x1e\n\x1aMODBUS_FUNCTION_WRITE_COIL\x10\x05\x12!\n\x1dMODBUS_FUNCTION_WRITE_HOLDING\x10\x06*l\n\nModbusUnit\x12\x1b\n\x17MODBUS_UNIT_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODBUS_UNIT_CM\x10\x64\x12\x13\n\x0fMODBUS_UNIT_CCV\x10\x7f\x12\x18\n\x13MODBUS_UNIT_OUTDOOR\x10\x82\x01\x42\xb5\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x0bModbusProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.modbus_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\013ModbusProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_MODBUSREGISTERTYPE']._serialized_start=607
  _globals['_MODBUSREGISTERTYPE']._serialized_end=903
  _globals['_MODBUSFUNCTION']._serialized_start=906
  _globals['_MODBUSFUNCTION']._serialized_end=1119
  _globals['_MODBUSUNIT']._serialized_start=1121
  _globals['_MODBUSUNIT']._serialized_end=1229
  _globals['_MODBUSRESPONSE']._serialized_start=73
  _globals['_MODBUSRESPONSE']._serialized_end=152
  _globals['_MODBUSREGISTERDATA']._serialized_start=155
  _globals['_MODBUSREGISTERDATA']._serialized_end=318
  _globals['_MODBUSREQUEST']._serialized_start=321
  _globals['_MODBUSREQUEST']._serialized_end=604
# @@protoc_insertion_point(module_scope)