# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/wall_thermostat/broadcast/v1/wall_thermostat_update.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/wall_thermostat/broadcast/v1/wall_thermostat_update.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@device/wall_thermostat/broadcast/v1/wall_thermostat_update.proto\x12#device.wall_thermostat.broadcast.v1\"\xa5\x01\n\x12WallThermostatInfo\x12\x12\n\nfw_version\x18\x01 \x01(\r\x12\x1a\n\x12\x62ootloader_version\x18\x02 \x01(\r\x12\x14\n\x0cwakeup_count\x18\x03 \x01(\r\x12\x14\n\x0creboot_count\x18\x04 \x01(\r\x12\x1a\n\x12setpoint_set_count\x18\x05 \x01(\r\x12\x17\n\x0f\x64hw_boost_count\x18\x06 \x01(\r\"\xae\x01\n\x14WallThermostatUpdate\x12\x1a\n\x12\x61\x63tual_temperature\x18\x01 \x01(\x05\x12\x10\n\x08humidity\x18\x02 \x01(\r\x12!\n\x19warning_low_battery_level\x18\x03 \x01(\x08\x12\x45\n\x04info\x18\x04 \x01(\x0b\x32\x37.device.wall_thermostat.broadcast.v1.WallThermostatInfoB\xeb\x01\n#device.wall_thermostat.broadcast.v1B\x19WallThermostatUpdateProtoP\x01\xa2\x02\x03\x44WB\xaa\x02\"Device.WallThermostat.Broadcast.V1\xca\x02\"Device\\WallThermostat\\Broadcast\\V1\xe2\x02.Device\\WallThermostat\\Broadcast\\V1\\GPBMetadata\xea\x02%Device::WallThermostat::Broadcast::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.wall_thermostat.broadcast.v1.wall_thermostat_update_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#device.wall_thermostat.broadcast.v1B\031WallThermostatUpdateProtoP\001\242\002\003DWB\252\002\"Device.WallThermostat.Broadcast.V1\312\002\"Device\\WallThermostat\\Broadcast\\V1\342\002.Device\\WallThermostat\\Broadcast\\V1\\GPBMetadata\352\002%Device::WallThermostat::Broadcast::V1'
  _globals['_WALLTHERMOSTATINFO']._serialized_start=106
  _globals['_WALLTHERMOSTATINFO']._serialized_end=271
  _globals['_WALLTHERMOSTATUPDATE']._serialized_start=274
  _globals['_WALLTHERMOSTATUPDATE']._serialized_end=448
# @@protoc_insertion_point(module_scope)