# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/v1/online.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/v1/online.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x64\x65vice/v1/online.proto\x12\tdevice.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"B\n\x06Online\x12\x0e\n\x06online\x18\x01 \x01(\x08\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB]\n\tdevice.v1B\x0bOnlineProtoP\x01\xa2\x02\x03\x44XX\xaa\x02\tDevice.V1\xca\x02\tDevice\\V1\xe2\x02\x15\x44\x65vice\\V1\\GPBMetadata\xea\x02\nDevice::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.v1.online_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tdevice.v1B\013OnlineProtoP\001\242\002\003DXX\252\002\tDevice.V1\312\002\tDevice\\V1\342\002\025Device\\V1\\GPBMetadata\352\002\nDevice::V1'
  _globals['_ONLINE']._serialized_start=70
  _globals['_ONLINE']._serialized_end=136
# @@protoc_insertion_point(module_scope)