# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/power/ble/v1/power_installation_state.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/power/ble/v1/power_installation_state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...peripheral.photovoltaics.v1 import config_pb2 as device_dot_power_dot_peripheral_dot_photovoltaics_dot_v1_dot_config__pb2
from ...peripheral.battery.v1 import config_pb2 as device_dot_power_dot_peripheral_dot_battery_dot_v1_dot_config__pb2
from ...grid.v1 import grid_code_preset_pb2 as device_dot_power_dot_grid_dot_v1_dot_grid__code__preset__pb2
from ...grid.v1 import config_pb2 as device_dot_power_dot_grid_dot_v1_dot_config__pb2
from ...controller.v1 import system_mode_pb2 as device_dot_power_dot_controller_dot_v1_dot_system__mode__pb2
from ...controller.v1 import current_transformer_pb2 as device_dot_power_dot_controller_dot_v1_dot_current__transformer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2device/power/ble/v1/power_installation_state.proto\x12\x13\x64\x65vice.power.ble.v1\x1a\x35\x64\x65vice/power/peripheral/photovoltaics/v1/config.proto\x1a/device/power/peripheral/battery/v1/config.proto\x1a+device/power/grid/v1/grid_code_preset.proto\x1a!device/power/grid/v1/config.proto\x1a,device/power/controller/v1/system_mode.proto\x1a\x34\x64\x65vice/power/controller/v1/current_transformer.proto\"\xab\x02\n\x14RuntimeConfiguration\x12\x34\n\x04mode\x18\x01 \x01(\x0e\x32&.device.power.controller.v1.SystemMode\x12\x35\n\x0bgrid_config\x18\x03 \x01(\x0b\x32 .device.power.grid.v1.GridConfig\x12I\n\x0e\x62\x61ttery_config\x18\x04 \x01(\x0b\x32\x31.device.power.peripheral.battery.v1.BatteryConfig\x12[\n\x14photovoltaics_config\x18\x05 \x01(\x0b\x32=.device.power.peripheral.photovoltaics.v1.PhotovoltaicsConfig\"i\n\x08Inverter\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x14\n\x0cpower_rating\x18\x03 \x01(\x02\x12\x16\n\x0e\x63urrent_rating\x18\x04 \x01(\x02\x12\n\n\x02id\x18\x05 \x01(\t\"\x96\x01\n\x07\x42\x61ttery\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x14\n\x0cpower_rating\x18\x03 \x01(\x02\x12\x17\n\x0f\x63\x61pacity_rating\x18\x04 \x01(\x02\x12\x15\n\rc_rate_rating\x18\x05 \x01(\x02\x12\x14\n\x0cmanufacturer\x18\x06 \x01(\x05\x12\n\n\x02id\x18\x08 \x01(\t\"V\n\rPhotovoltaics\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x14\n\x0cpower_rating\x18\x03 \x01(\x02\x12\n\n\x02id\x18\x04 \x01(\t\"\xab\x01\n\x0cPowerDevices\x12/\n\x08inverter\x18\x01 \x03(\x0b\x32\x1d.device.power.ble.v1.Inverter\x12\x39\n\rphotovoltaics\x18\x02 \x03(\x0b\x32\".device.power.ble.v1.Photovoltaics\x12/\n\tbatteries\x18\x03 \x03(\x0b\x32\x1c.device.power.ble.v1.Battery\"\xad\x01\n\x15\x46\x61\x63ilityConfiguration\x12\x11\n\tmain_fuse\x18\x01 \x01(\x02\x12?\n\x06phases\x18\x02 \x01(\x0e\x32/.device.power.ble.v1.FacilityPhaseConfiguration\x12\x1f\n\x17\x61\x63tive_power_rating_neg\x18\x03 \x01(\x02\x12\x1f\n\x17\x61\x63tive_power_rating_pos\x18\x04 \x01(\x02\"\xd2\x03\n\x16PowerInstallationState\x12\x1a\n\x12paired_core_serial\x18\x01 \x01(\t\x12\x1f\n\x17paired_core_app_version\x18\x02 \x01(\t\x12>\n\x10grid_code_preset\x18\x03 \x01(\x0e\x32$.device.power.grid.v1.GridCodePreset\x12J\n\x16\x66\x61\x63ility_configuration\x18\x04 \x01(\x0b\x32*.device.power.ble.v1.FacilityConfiguration\x12\x32\n\x07\x64\x65vices\x18\x05 \x01(\x0b\x32!.device.power.ble.v1.PowerDevices\x12\x19\n\x11microgrid_powered\x18\x06 \x01(\x08\x12V\n\x19\x63urrent_transformer_state\x18\x07 \x01(\x0b\x32\x33.device.power.controller.v1.CurrentTransformerState\x12H\n\x15runtime_configuration\x18\x08 \x01(\x0b\x32).device.power.ble.v1.RuntimeConfiguration*\x9b\x01\n\x1a\x46\x61\x63ilityPhaseConfiguration\x12,\n(FACILITY_PHASE_CONFIGURATION_UNSPECIFIED\x10\x00\x12\'\n#FACILITY_PHASE_CONFIGURATION_SINGLE\x10\x01\x12&\n\"FACILITY_PHASE_CONFIGURATION_THREE\x10\x02\x42\xa1\x01\n\x13\x64\x65vice.power.ble.v1B\x1bPowerInstallationStateProtoP\x01\xa2\x02\x03\x44PB\xaa\x02\x13\x44\x65vice.Power.Ble.V1\xca\x02\x13\x44\x65vice\\Power\\Ble\\V1\xe2\x02\x1f\x44\x65vice\\Power\\Ble\\V1\\GPBMetadata\xea\x02\x16\x44\x65vice::Power::Ble::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.power.ble.v1.power_installation_state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023device.power.ble.v1B\033PowerInstallationStateProtoP\001\242\002\003DPB\252\002\023Device.Power.Ble.V1\312\002\023Device\\Power\\Ble\\V1\342\002\037Device\\Power\\Ble\\V1\\GPBMetadata\352\002\026Device::Power::Ble::V1'
  _globals['_FACILITYPHASECONFIGURATION']._serialized_start=1829
  _globals['_FACILITYPHASECONFIGURATION']._serialized_end=1984
  _globals['_RUNTIMECONFIGURATION']._serialized_start=360
  _globals['_RUNTIMECONFIGURATION']._serialized_end=659
  _globals['_INVERTER']._serialized_start=661
  _globals['_INVERTER']._serialized_end=766
  _globals['_BATTERY']._serialized_start=769
  _globals['_BATTERY']._serialized_end=919
  _globals['_PHOTOVOLTAICS']._serialized_start=921
  _globals['_PHOTOVOLTAICS']._serialized_end=1007
  _globals['_POWERDEVICES']._serialized_start=1010
  _globals['_POWERDEVICES']._serialized_end=1181
  _globals['_FACILITYCONFIGURATION']._serialized_start=1184
  _globals['_FACILITYCONFIGURATION']._serialized_end=1357
  _globals['_POWERINSTALLATIONSTATE']._serialized_start=1360
  _globals['_POWERINSTALLATIONSTATE']._serialized_end=1826
# @@protoc_insertion_point(module_scope)