# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import service_pb2 as device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in device/heat_pump/statistics/v1/service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class HeatPumpStatisticsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHeatPumpInsights = channel.unary_unary(
                '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetHeatPumpInsights',
                request_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsResponse.FromString,
                _registered_method=True)
        self.GetCop = channel.unary_unary(
                '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetCop',
                request_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopResponse.FromString,
                _registered_method=True)
        self.GetOptimisationSavings = channel.unary_unary(
                '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetOptimisationSavings',
                request_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsResponse.FromString,
                _registered_method=True)
        self.GetSavings = channel.unary_unary(
                '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetSavings',
                request_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsResponse.FromString,
                _registered_method=True)


class HeatPumpStatisticsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetHeatPumpInsights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOptimisationSavings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSavings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HeatPumpStatisticsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetHeatPumpInsights': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHeatPumpInsights,
                    request_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsResponse.SerializeToString,
            ),
            'GetCop': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCop,
                    request_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopResponse.SerializeToString,
            ),
            'GetOptimisationSavings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOptimisationSavings,
                    request_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsResponse.SerializeToString,
            ),
            'GetSavings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSavings,
                    request_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'device.heat_pump.statistics.v1.HeatPumpStatisticsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('device.heat_pump.statistics.v1.HeatPumpStatisticsService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class HeatPumpStatisticsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetHeatPumpInsights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetHeatPumpInsights',
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsRequest.SerializeToString,
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetCop',
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopRequest.SerializeToString,
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOptimisationSavings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetOptimisationSavings',
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsRequest.SerializeToString,
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSavings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetSavings',
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsRequest.SerializeToString,
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)