# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/power/controller/v1/system_mode.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/power/controller/v1/system_mode.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,device/power/controller/v1/system_mode.proto\x12\x1a\x64\x65vice.power.controller.v1*\x9f\x01\n\nSystemMode\x12\x1b\n\x17SYSTEM_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13SYSTEM_MODE_DEFAULT\x10\x01\x12 \n\x1cSYSTEM_MODE_SELF_CONSUMPTION\x10\x02\x12\x1c\n\x18SYSTEM_MODE_PEAK_SHAVING\x10\x03\x12\x1b\n\x17SYSTEM_MODE_MEASUREMENT\x10\x04\x42\xb8\x01\n\x1a\x64\x65vice.power.controller.v1B\x0fSystemModeProtoP\x01\xa2\x02\x03\x44PC\xaa\x02\x1a\x44\x65vice.Power.Controller.V1\xca\x02\x1a\x44\x65vice\\Power\\Controller\\V1\xe2\x02&Device\\Power\\Controller\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::Power::Controller::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.power.controller.v1.system_mode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032device.power.controller.v1B\017SystemModeProtoP\001\242\002\003DPC\252\002\032Device.Power.Controller.V1\312\002\032Device\\Power\\Controller\\V1\342\002&Device\\Power\\Controller\\V1\\GPBMetadata\352\002\035Device::Power::Controller::V1'
  _globals['_SYSTEMMODE']._serialized_start=77
  _globals['_SYSTEMMODE']._serialized_end=236
# @@protoc_insertion_point(module_scope)