# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/command_progress.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/command_progress.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import modbus_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_modbus__pb2
from . import command_error_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2device/heat_pump/command/v1/command_progress.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\x1a\x12util/v1/uuid.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a(device/heat_pump/command/v1/modbus.proto\x1a/device/heat_pump/command/v1/command_error.proto\"\xef\x04\n\x0f\x43ommandProgress\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15\x61ws_iot_received_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x08received\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12:\n\x05\x65rror\x18\x05 \x01(\x0b\x32).device.heat_pump.command.v1.CommandErrorH\x00\x12+\n\tsucceeded\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12&\n\x04sent\x18\x07 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x31\n\x0f\x66ile_downloaded\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rfile_uploaded\x18\t \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rfile_verified\x18\n \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x30\n\x0e\x66ile_installed\x18\x0b \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x46\n\x0fmodbus_response\x18\x0c \x01(\x0b\x32+.device.heat_pump.command.v1.ModbusResponseH\x00\x42\x08\n\x06group0B\xbe\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x14\x43ommandProgressProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.command_progress_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\024CommandProgressProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_COMMANDPROGRESS']._serialized_start=257
  _globals['_COMMANDPROGRESS']._serialized_end=880
# @@protoc_insertion_point(module_scope)