# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_account/v2/user_account.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'user_account/v2/user_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...util.v2 import market_pb2 as util_dot_v2_dot_market__pb2
from ...util.v2 import locale_pb2 as util_dot_v2_dot_locale__pb2
from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from . import role_pb2 as user__account_dot_v2_dot_role__pb2
from ...notification.v2 import notification_pb2 as notification_dot_v2_dot_notification__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"user_account/v2/user_account.proto\x12\x0fuser_account.v2\x1a\x14util/v2/market.proto\x1a\x14util/v2/locale.proto\x1a\x12util/v1/uuid.proto\x1a\x1auser_account/v2/role.proto\x1a\"notification/v2/notification.proto\x1a\x1fgoogle/protobuf/timestamp.proto\":\n\x17VerifyProximityResponse\x12\x1f\n\x17verification_successful\x18\x01 \x01(\x08\"D\n\x16VerifyProximityRequest\x12*\n\x13\x63lose_heat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v1.Uuid\"s\n&GetProximityVerificationStatusResponse\x12I\n\x13verification_status\x18\x01 \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatus\"\'\n%GetProximityVerificationStatusRequest\"\x18\n\x16\x44\x65leteResidentResponse\"\x9d\x01\n\x15\x44\x65leteResidentRequest\x12)\n\x12\x65ngagement_user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12#\n\x0chousehold_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12\x34\n\x1d\x64\x65leted_by_engagement_user_id\x18\x03 \x01(\x0b\x32\r.util.v1.Uuid\"\xb7\x01\n\x08Resident\x12)\n\x12\x65ngagement_user_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12#\n\x0chousehold_id\x18\x03 \x01(\x0b\x32\r.util.v1.Uuid\x12\x12\n\ngiven_name\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12#\n\x04role\x18\x07 \x01(\x0e\x32\x15.user_account.v2.Role\"%\n\x08HeatPump\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"\xb4\x01\n\tHousehold\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\tresidents\x18\x03 \x03(\x0b\x32\x19.user_account.v2.Resident\x12,\n\theat_pump\x18\x04 \x01(\x0b\x32\x19.user_account.v2.HeatPump\x12\"\n\x0b\x66\x61\x63ility_id\x18\x05 \x01(\x0b\x32\r.util.v1.Uuid\"O\n\x1dGetHouseholdsByUserIdResponse\x12.\n\nhouseholds\x18\x01 \x03(\x0b\x32\x1a.user_account.v2.Household\"I\n\x1cGetHouseholdsByUserIdRequest\x12)\n\x12\x65ngagement_user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"n\n+UserHasAcceptedLatestLegalDocumentsResponse\x12?\n\nagreements\x18\x01 \x03(\x0b\x32+.user_account.v2.LegalDocumentUserAgreement\"L\n*UserHasAcceptedLatestLegalDocumentsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"*\n(CreateLegalDocumentUserAgreementResponse\"s\n\'CreateLegalDocumentUserAgreementRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12(\n\x11legal_document_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\"\xa5\x01\n\x1aLegalDocumentUserAgreement\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12/\n\x0b\x61\x63\x63\x65pted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x0elegal_document\x18\x03 \x01(\x0b\x32\x1e.user_account.v2.LegalDocument\"\xc3\x01\n\rLegalDocument\x12\"\n\x0b\x64ocument_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x39\n\rdocument_type\x18\x03 \x01(\x0e\x32\".user_account.v2.LegalDocumentType\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x1f\n\x06market\x18\x05 \x01(\x0e\x32\x0f.util.v2.Market\x12\x10\n\x08web_link\x18\x06 \x01(\t\"O\n\x19UpdateUserAccountResponse\x12\x32\n\x0cuser_account\x18\x01 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\"\xfc\x01\n\x18UpdateUserAccountRequest\x12\x1e\n\x07user_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12!\n\ncontact_id\x18\x03 \x01(\x0b\x32\r.util.v1.Uuid\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x07 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x08 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\t \x01(\x08\"\x87\x01\n!GetUserAccountByCognitoIdResponse\x12\x32\n\x0cuser_account\x18\x02 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\x12.\n\nhouseholds\x18\x03 \x03(\x0b\x32\x1a.user_account.v2.Household\"E\n GetUserAccountByCognitoIdRequest\x12!\n\ncognito_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"\x96\x03\n\x0bUserAccount\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12!\n\ncontact_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x08 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\t \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\n \x01(\x08\x12!\n\ncognito_id\x18\x0b \x01(\x0b\x32\r.util.v1.Uuid\x12\x1e\n\x16phone_number_confirmed\x18\x0c \x01(\x08\x12S\n\x1dproximity_verification_status\x18\r \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatus\"Z\n\"GetFeaturesAsNotificationsResponse\x12\x34\n\rnotifications\x18\x01 \x03(\x0b\x32\x1d.notification.v2.Notification\"D\n!GetFeaturesAsNotificationsRequest\x12\x1f\n\x06locale\x18\x01 \x01(\x0e\x32\x0f.util.v2.Locale\"\x1c\n\x1a\x43onfirmPhoneNumberResponse\"\x82\x01\n\x19\x43onfirmPhoneNumberRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x14\n\x0cphone_number\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x04 \x01(\t\"\x1c\n\x1a\x43onfirmEmailChangeResponse\"\x7f\n\x19\x43onfirmEmailChangeRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x11\n\tnew_email\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x04 \x01(\t\")\n\tZoneNames\x12\r\n\x05zone1\x18\x01 \x01(\t\x12\r\n\x05zone2\x18\x02 \x01(\t\"N\n\x1cGetHeatPumpZoneNamesResponse\x12.\n\nzone_names\x18\x01 \x01(\x0b\x32\x1a.user_account.v2.ZoneNames\"B\n\x1bGetHeatPumpZoneNamesRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid*\xd6\x01\n\x1bProximityVerificationStatus\x12-\n)PROXIMITY_VERIFICATION_STATUS_UNSPECIFIED\x10\x00\x12.\n*PROXIMITY_VERIFICATION_STATUS_NOT_VERIFIED\x10\x01\x12*\n&PROXIMITY_VERIFICATION_STATUS_VERIFIED\x10\x02\x12,\n(PROXIMITY_VERIFICATION_STATUS_NOT_NEEDED\x10\x03*\x8a\x01\n\x11LegalDocumentType\x12#\n\x1fLEGAL_DOCUMENT_TYPE_UNSPECIFIED\x10\x00\x12(\n$LEGAL_DOCUMENT_TYPE_TERMS_OF_SERVICE\x10\x01\x12&\n\"LEGAL_DOCUMENT_TYPE_PRIVACY_POLICY\x10\x02\x32\xf2\x0b\n\x12UserAccountService\x12\x82\x01\n\x19GetUserAccountByCognitoId\x12\x31.user_account.v2.GetUserAccountByCognitoIdRequest\x1a\x32.user_account.v2.GetUserAccountByCognitoIdResponse\x12m\n\x12\x43onfirmPhoneNumber\x12*.user_account.v2.ConfirmPhoneNumberRequest\x1a+.user_account.v2.ConfirmPhoneNumberResponse\x12j\n\x11UpdateUserAccount\x12).user_account.v2.UpdateUserAccountRequest\x1a*.user_account.v2.UpdateUserAccountResponse\x12m\n\x12\x43onfirmEmailChange\x12*.user_account.v2.ConfirmEmailChangeRequest\x1a+.user_account.v2.ConfirmEmailChangeResponse\x12\x85\x01\n\x1aGetFeaturesAsNotifications\x12\x32.user_account.v2.GetFeaturesAsNotificationsRequest\x1a\x33.user_account.v2.GetFeaturesAsNotificationsResponse\x12\x61\n\x0e\x44\x65leteResident\x12&.user_account.v2.DeleteResidentRequest\x1a\'.user_account.v2.DeleteResidentResponse\x12\x64\n\x0fVerifyProximity\x12\'.user_account.v2.VerifyProximityRequest\x1a(.user_account.v2.VerifyProximityResponse\x12s\n\x14GetHeatPumpZoneNames\x12,.user_account.v2.GetHeatPumpZoneNamesRequest\x1a-.user_account.v2.GetHeatPumpZoneNamesResponse\x12\xa0\x01\n#UserHasAcceptedLatestLegalDocuments\x12;.user_account.v2.UserHasAcceptedLatestLegalDocumentsRequest\x1a<.user_account.v2.UserHasAcceptedLatestLegalDocumentsResponse\x12\x97\x01\n CreateLegalDocumentUserAgreement\x12\x38.user_account.v2.CreateLegalDocumentUserAgreementRequest\x1a\x39.user_account.v2.CreateLegalDocumentUserAgreementResponse\x12v\n\x15GetHouseholdsByUserId\x12-.user_account.v2.GetHouseholdsByUserIdRequest\x1a..user_account.v2.GetHouseholdsByUserIdResponse\x12\x91\x01\n\x1eGetProximityVerificationStatus\x12\x36.user_account.v2.GetProximityVerificationStatusRequest\x1a\x37.user_account.v2.GetProximityVerificationStatusResponseB|\n\x0fuser_account.v2B\x10UserAccountProtoP\x01\xa2\x02\x03UXX\xaa\x02\x0eUserAccount.V2\xca\x02\x0eUserAccount\\V2\xe2\x02\x1aUserAccount\\V2\\GPBMetadata\xea\x02\x0fUserAccount::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_account.v2.user_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017user_account.v2B\020UserAccountProtoP\001\242\002\003UXX\252\002\016UserAccount.V2\312\002\016UserAccount\\V2\342\002\032UserAccount\\V2\\GPBMetadata\352\002\017UserAccount::V2'
  _globals['_PROXIMITYVERIFICATIONSTATUS']._serialized_start=3601
  _globals['_PROXIMITYVERIFICATIONSTATUS']._serialized_end=3815
  _globals['_LEGALDOCUMENTTYPE']._serialized_start=3818
  _globals['_LEGALDOCUMENTTYPE']._serialized_end=3956
  _globals['_VERIFYPROXIMITYRESPONSE']._serialized_start=216
  _globals['_VERIFYPROXIMITYRESPONSE']._serialized_end=274
  _globals['_VERIFYPROXIMITYREQUEST']._serialized_start=276
  _globals['_VERIFYPROXIMITYREQUEST']._serialized_end=344
  _globals['_GETPROXIMITYVERIFICATIONSTATUSRESPONSE']._serialized_start=346
  _globals['_GETPROXIMITYVERIFICATIONSTATUSRESPONSE']._serialized_end=461
  _globals['_GETPROXIMITYVERIFICATIONSTATUSREQUEST']._serialized_start=463
  _globals['_GETPROXIMITYVERIFICATIONSTATUSREQUEST']._serialized_end=502
  _globals['_DELETERESIDENTRESPONSE']._serialized_start=504
  _globals['_DELETERESIDENTRESPONSE']._serialized_end=528
  _globals['_DELETERESIDENTREQUEST']._serialized_start=531
  _globals['_DELETERESIDENTREQUEST']._serialized_end=688
  _globals['_RESIDENT']._serialized_start=691
  _globals['_RESIDENT']._serialized_end=874
  _globals['_HEATPUMP']._serialized_start=876
  _globals['_HEATPUMP']._serialized_end=913
  _globals['_HOUSEHOLD']._serialized_start=916
  _globals['_HOUSEHOLD']._serialized_end=1096
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_start=1098
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_end=1177
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_start=1179
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_end=1252
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSRESPONSE']._serialized_start=1254
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSRESPONSE']._serialized_end=1364
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSREQUEST']._serialized_start=1366
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSREQUEST']._serialized_end=1442
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTRESPONSE']._serialized_start=1444
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTRESPONSE']._serialized_end=1486
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTREQUEST']._serialized_start=1488
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTREQUEST']._serialized_end=1603
  _globals['_LEGALDOCUMENTUSERAGREEMENT']._serialized_start=1606
  _globals['_LEGALDOCUMENTUSERAGREEMENT']._serialized_end=1771
  _globals['_LEGALDOCUMENT']._serialized_start=1774
  _globals['_LEGALDOCUMENT']._serialized_end=1969
  _globals['_UPDATEUSERACCOUNTRESPONSE']._serialized_start=1971
  _globals['_UPDATEUSERACCOUNTRESPONSE']._serialized_end=2050
  _globals['_UPDATEUSERACCOUNTREQUEST']._serialized_start=2053
  _globals['_UPDATEUSERACCOUNTREQUEST']._serialized_end=2305
  _globals['_GETUSERACCOUNTBYCOGNITOIDRESPONSE']._serialized_start=2308
  _globals['_GETUSERACCOUNTBYCOGNITOIDRESPONSE']._serialized_end=2443
  _globals['_GETUSERACCOUNTBYCOGNITOIDREQUEST']._serialized_start=2445
  _globals['_GETUSERACCOUNTBYCOGNITOIDREQUEST']._serialized_end=2514
  _globals['_USERACCOUNT']._serialized_start=2517
  _globals['_USERACCOUNT']._serialized_end=2923
  _globals['_GETFEATURESASNOTIFICATIONSRESPONSE']._serialized_start=2925
  _globals['_GETFEATURESASNOTIFICATIONSRESPONSE']._serialized_end=3015
  _globals['_GETFEATURESASNOTIFICATIONSREQUEST']._serialized_start=3017
  _globals['_GETFEATURESASNOTIFICATIONSREQUEST']._serialized_end=3085
  _globals['_CONFIRMPHONENUMBERRESPONSE']._serialized_start=3087
  _globals['_CONFIRMPHONENUMBERRESPONSE']._serialized_end=3115
  _globals['_CONFIRMPHONENUMBERREQUEST']._serialized_start=3118
  _globals['_CONFIRMPHONENUMBERREQUEST']._serialized_end=3248
  _globals['_CONFIRMEMAILCHANGERESPONSE']._serialized_start=3250
  _globals['_CONFIRMEMAILCHANGERESPONSE']._serialized_end=3278
  _globals['_CONFIRMEMAILCHANGEREQUEST']._serialized_start=3280
  _globals['_CONFIRMEMAILCHANGEREQUEST']._serialized_end=3407
  _globals['_ZONENAMES']._serialized_start=3409
  _globals['_ZONENAMES']._serialized_end=3450
  _globals['_GETHEATPUMPZONENAMESRESPONSE']._serialized_start=3452
  _globals['_GETHEATPUMPZONENAMESRESPONSE']._serialized_end=3530
  _globals['_GETHEATPUMPZONENAMESREQUEST']._serialized_start=3532
  _globals['_GETHEATPUMPZONENAMESREQUEST']._serialized_end=3598
  _globals['_USERACCOUNTSERVICE']._serialized_start=3959
  _globals['_USERACCOUNTSERVICE']._serialized_end=5481
# @@protoc_insertion_point(module_scope)