# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: notification/v2/notification_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'notification/v2/notification_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from . import notification_pb2 as notification_dot_v2_dot_notification__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*notification/v2/notification_service.proto\x12\x0fnotification.v2\x1a\x12util/v1/uuid.proto\x1a\"notification/v2/notification.proto\x1a\x1fgoogle/protobuf/timestamp.proto\" \n\x1eRemoveFcmTokenFromUserResponse\"N\n\x1dRemoveFcmTokenFromUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05token\x18\x02 \x01(\t\"\x1b\n\x19\x41\x64\x64\x46\x63mTokenToUserResponse\"I\n\x18\x41\x64\x64\x46\x63mTokenToUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05token\x18\x02 \x01(\t\"P\n\x18GetNotificationsResponse\x12\x34\n\rnotifications\x18\x01 \x03(\x0b\x32\x1d.notification.v2.Notification\"o\n\x17GetNotificationsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x34\n\x10\x63reated_at_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xe5\x02\n\x13NotificationService\x12g\n\x10GetNotifications\x12(.notification.v2.GetNotificationsRequest\x1a).notification.v2.GetNotificationsResponse\x12j\n\x11\x41\x64\x64\x46\x63mTokenToUser\x12).notification.v2.AddFcmTokenToUserRequest\x1a*.notification.v2.AddFcmTokenToUserResponse\x12y\n\x16RemoveFcmTokenFromUser\x12..notification.v2.RemoveFcmTokenFromUserRequest\x1a/.notification.v2.RemoveFcmTokenFromUserResponseB\x88\x01\n\x0fnotification.v2B\x18NotificationServiceProtoP\x01\xa2\x02\x03NXX\xaa\x02\x0fNotification.V2\xca\x02\x0fNotification\\V2\xe2\x02\x1bNotification\\V2\\GPBMetadata\xea\x02\x10Notification::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification.v2.notification_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017notification.v2B\030NotificationServiceProtoP\001\242\002\003NXX\252\002\017Notification.V2\312\002\017Notification\\V2\342\002\033Notification\\V2\\GPBMetadata\352\002\020Notification::V2'
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_start=152
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_end=184
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_start=186
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_end=264
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_start=266
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_end=293
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_start=295
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_end=368
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_start=370
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_end=450
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_start=452
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_end=563
  _globals['_NOTIFICATIONSERVICE']._serialized_start=566
  _globals['_NOTIFICATIONSERVICE']._serialized_end=923
# @@protoc_insertion_point(module_scope)