# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/action.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'schedule/v1/action.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18schedule/v1/action.proto\x12\x0bschedule.v1\"\x13\n\x11SetAntiLegionella\"\x0e\n\x0cPostAwayMode\".\n\x0bSetAwayMode\x12\x1f\n\x17target_room_temperature\x18\x01 \x01(\x02\"\x19\n\x0bSetDhwBoost\x12\n\n\x02on\x18\x01 \x01(\x08\"\x97\x01\n\x14SetRoomSetpointDelta\x12\x34\n\x04zone\x18\x01 \x01(\x0e\x32&.schedule.v1.SetRoomSetpointDelta.Zone\x12\x13\n\x0btemperature\x18\x02 \x01(\x02\"4\n\x04Zone\x12\x14\n\x10ZONE_UNSPECIFIED\x10\x00\x12\n\n\x06ZONE_1\x10\x01\x12\n\n\x06ZONE_2\x10\x02\"%\n\x0eSetDhwSetpoint\x12\x13\n\x0btemperature\x18\x01 \x01(\x02\"*\n\x13SetDhwSetpointDelta\x12\x13\n\x0btemperature\x18\x01 \x01(\x02\")\n\x12SetRoomSupplyDelta\x12\x13\n\x0btemperature\x18\x01 \x01(\x02\"\x9d\x04\n\x11SetFerroampConfig\x12\x37\n\x04mode\x18\x01 \x01(\x0e\x32).schedule.v1.SetFerroampConfig.SystemMode\x12>\n\x0bgrid_config\x18\x02 \x01(\x0b\x32).schedule.v1.SetFerroampConfig.GridConfig\x12\x44\n\x0e\x62\x61ttery_config\x18\x03 \x01(\x0b\x32,.schedule.v1.SetFerroampConfig.BatteryConfig\x1a\x32\n\rBatteryConfig\x12\x0e\n\x06\x63harge\x18\x01 \x01(\x08\x12\x11\n\tdischarge\x18\x02 \x01(\x08\x1as\n\nGridConfig\x12\x14\n\x0climit_import\x18\x01 \x01(\x08\x12\x14\n\x0climit_export\x18\x02 \x01(\x08\x12\x1b\n\x13power_threshold_low\x18\x03 \x01(\x02\x12\x1c\n\x14power_threshold_high\x18\x04 \x01(\x02\"\x9f\x01\n\nSystemMode\x12\x1b\n\x17SYSTEM_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13SYSTEM_MODE_DEFAULT\x10\x01\x12 \n\x1cSYSTEM_MODE_SELF_CONSUMPTION\x10\x02\x12\x1c\n\x18SYSTEM_MODE_PEAK_SHAVING\x10\x03\x12\x1b\n\x17SYSTEM_MODE_MEASUREMENT\x10\x04\"\x12\n\x10SetChargeBattery\"\x0e\n\x0cSetNightMode\"O\n\x11SetHeatCurveDelta\x12\n\n\x02p1\x18\x01 \x01(\x02\x12\n\n\x02p2\x18\x02 \x01(\x02\x12\n\n\x02p3\x18\x03 \x01(\x02\x12\n\n\x02p4\x18\x04 \x01(\x02\x12\n\n\x02p5\x18\x05 \x01(\x02\"\xe2\x05\n\x06\x41\x63tion\x12\x44\n\x17set_room_setpoint_delta\x18\x01 \x01(\x0b\x32!.schedule.v1.SetRoomSetpointDeltaH\x00\x12\x42\n\x16set_dhw_setpoint_delta\x18\x02 \x01(\x0b\x32 .schedule.v1.SetDhwSetpointDeltaH\x00\x12\x31\n\rset_dhw_boost\x18\x03 \x01(\x0b\x32\x18.schedule.v1.SetDhwBoostH\x00\x12\x37\n\x10set_dhw_setpoint\x18\x04 \x01(\x0b\x32\x1b.schedule.v1.SetDhwSetpointH\x00\x12\x31\n\rset_away_mode\x18\x05 \x01(\x0b\x32\x18.schedule.v1.SetAwayModeH\x00\x12=\n\x13set_anti_legionella\x18\x06 \x01(\x0b\x32\x1e.schedule.v1.SetAntiLegionellaH\x00\x12@\n\x15set_room_supply_delta\x18\x07 \x01(\x0b\x32\x1f.schedule.v1.SetRoomSupplyDeltaH\x00\x12\x33\n\x0epost_away_mode\x18\x08 \x01(\x0b\x32\x19.schedule.v1.PostAwayModeH\x00\x12=\n\x13set_ferroamp_config\x18\t \x01(\x0b\x32\x1e.schedule.v1.SetFerroampConfigH\x00\x12;\n\x12set_charge_battery\x18\n \x01(\x0b\x32\x1d.schedule.v1.SetChargeBatteryH\x00\x12>\n\x14set_heat_curve_delta\x18\x0b \x01(\x0b\x32\x1e.schedule.v1.SetHeatCurveDeltaH\x00\x12\x33\n\x0eset_night_mode\x18\x0c \x01(\x0b\x32\x19.schedule.v1.SetNightModeH\x00\x42\x08\n\x06group0Bg\n\x0bschedule.v1B\x0b\x41\x63tionProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.action_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013schedule.v1B\013ActionProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_SETANTILEGIONELLA']._serialized_start=41
  _globals['_SETANTILEGIONELLA']._serialized_end=60
  _globals['_POSTAWAYMODE']._serialized_start=62
  _globals['_POSTAWAYMODE']._serialized_end=76
  _globals['_SETAWAYMODE']._serialized_start=78
  _globals['_SETAWAYMODE']._serialized_end=124
  _globals['_SETDHWBOOST']._serialized_start=126
  _globals['_SETDHWBOOST']._serialized_end=151
  _globals['_SETROOMSETPOINTDELTA']._serialized_start=154
  _globals['_SETROOMSETPOINTDELTA']._serialized_end=305
  _globals['_SETROOMSETPOINTDELTA_ZONE']._serialized_start=253
  _globals['_SETROOMSETPOINTDELTA_ZONE']._serialized_end=305
  _globals['_SETDHWSETPOINT']._serialized_start=307
  _globals['_SETDHWSETPOINT']._serialized_end=344
  _globals['_SETDHWSETPOINTDELTA']._serialized_start=346
  _globals['_SETDHWSETPOINTDELTA']._serialized_end=388
  _globals['_SETROOMSUPPLYDELTA']._serialized_start=390
  _globals['_SETROOMSUPPLYDELTA']._serialized_end=431
  _globals['_SETFERROAMPCONFIG']._serialized_start=434
  _globals['_SETFERROAMPCONFIG']._serialized_end=975
  _globals['_SETFERROAMPCONFIG_BATTERYCONFIG']._serialized_start=646
  _globals['_SETFERROAMPCONFIG_BATTERYCONFIG']._serialized_end=696
  _globals['_SETFERROAMPCONFIG_GRIDCONFIG']._serialized_start=698
  _globals['_SETFERROAMPCONFIG_GRIDCONFIG']._serialized_end=813
  _globals['_SETFERROAMPCONFIG_SYSTEMMODE']._serialized_start=816
  _globals['_SETFERROAMPCONFIG_SYSTEMMODE']._serialized_end=975
  _globals['_SETCHARGEBATTERY']._serialized_start=977
  _globals['_SETCHARGEBATTERY']._serialized_end=995
  _globals['_SETNIGHTMODE']._serialized_start=997
  _globals['_SETNIGHTMODE']._serialized_end=1011
  _globals['_SETHEATCURVEDELTA']._serialized_start=1013
  _globals['_SETHEATCURVEDELTA']._serialized_end=1092
  _globals['_ACTION']._serialized_start=1095
  _globals['_ACTION']._serialized_end=1833
# @@protoc_insertion_point(module_scope)