# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: util/v1/uuid.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'util/v1/uuid.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12util/v1/uuid.proto\x12\x07util.v1\"\x15\n\x04Uuid\x12\r\n\x05value\x18\x01 \x01(\x0c\x42Q\n\x07util.v1B\tUuidProtoP\x01\xa2\x02\x03UXX\xaa\x02\x07Util.V1\xca\x02\x07Util\\V1\xe2\x02\x13Util\\V1\\GPBMetadata\xea\x02\x08Util::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'util.v1.uuid_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\007util.v1B\tUuidProtoP\001\242\002\003UXX\252\002\007Util.V1\312\002\007Util\\V1\342\002\023Util\\V1\\GPBMetadata\352\002\010Util::V1'
  _globals['_UUID']._serialized_start=31
  _globals['_UUID']._serialized_end=52
# @@protoc_insertion_point(module_scope)