# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/set_telemetry_interval.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/set_telemetry_interval.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8device/heat_pump/command/v1/set_telemetry_interval.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\x1a\x1egoogle/protobuf/duration.proto\"\xd8\x03\n\x14SetTelemetryInterval\x12\x34\n\x11sampling_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12W\n\x0etelemetry_type\x18\x02 \x01(\x0e\x32?.device.heat_pump.command.v1.SetTelemetryInterval.TelemetryType\"\xb0\x02\n\rTelemetryType\x12\x1e\n\x1aTELEMETRY_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cTELEMETRY_TYPE_SENSOR_VALUES\x10\x01\x12\x17\n\x12TELEMETRY_TYPE_DHW\x10\xe9\x07\x12\x1a\n\x15TELEMETRY_TYPE_STATUS\x10\xea\x07\x12\'\n\"TELEMETRY_TYPE_OUTDOOR_UNIT_STATUS\x10\xeb\x07\x12\x1c\n\x17TELEMETRY_TYPE_SETTINGS\x10\xec\x07\x12\x1a\n\x15TELEMETRY_TYPE_OUTPUT\x10\xed\x07\x12\x1c\n\x17TELEMETRY_TYPE_VERSIONS\x10\xee\x07\x12\'\n\"TELEMETRY_TYPE_OUTDOOR_UNIT_OUTPUT\x10\xef\x07*\xdf\x01\n\x19SetTelemetryIntervalError\x12,\n(SET_TELEMETRY_INTERVAL_ERROR_UNSPECIFIED\x10\x00\x12\x31\n-SET_TELEMETRY_INTERVAL_ERROR_TYPE_UNSPECIFIED\x10\x01\x12\x31\n-SET_TELEMETRY_INTERVAL_ERROR_INVALID_INTERVAL\x10\x02\x12.\n*SET_TELEMETRY_INTERVAL_ERROR_VALUE_TOO_LOW\x10\x03\x42\xc3\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x19SetTelemetryIntervalProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.set_telemetry_interval_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\031SetTelemetryIntervalProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_SETTELEMETRYINTERVALERROR']._serialized_start=597
  _globals['_SETTELEMETRYINTERVALERROR']._serialized_end=820
  _globals['_SETTELEMETRYINTERVAL']._serialized_start=122
  _globals['_SETTELEMETRYINTERVAL']._serialized_end=594
  _globals['_SETTELEMETRYINTERVAL_TELEMETRYTYPE']._serialized_start=290
  _globals['_SETTELEMETRYINTERVAL_TELEMETRYTYPE']._serialized_end=594
# @@protoc_insertion_point(module_scope)