# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/event.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'schedule/v1/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import rrule_pb2 as schedule_dot_v1_dot_rrule__pb2
from . import action_pb2 as schedule_dot_v1_dot_action__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17schedule/v1/event.proto\x12\x0bschedule.v1\x1a\x17schedule/v1/rrule.proto\x1a\x18schedule/v1/action.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xae\x02\n\x05\x45vent\x12/\n\x0b\x65vent_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tevent_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x05rrule\x18\x03 \x01(\x0b\x32\x12.schedule.v1.RRule\x12#\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x13.schedule.v1.Action\x12\x16\n\x0e\x65vent_start_dt\x18\x05 \x01(\t\x12\x14\n\x0c\x65vent_end_dt\x18\x06 \x01(\t\x12\x31\n\x0eremaining_time\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0e\n\x06\x61\x63tive\x18\x08 \x01(\x08\x12\x0c\n\x04name\x18\t \x01(\t\",\n\x06\x45vents\x12\"\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x12.schedule.v1.EventBf\n\x0bschedule.v1B\nEventProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013schedule.v1B\nEventProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_EVENT']._serialized_start=157
  _globals['_EVENT']._serialized_end=459
  _globals['_EVENTS']._serialized_start=461
  _globals['_EVENTS']._serialized_end=505
# @@protoc_insertion_point(module_scope)