# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/schedule.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'schedule/v1/schedule.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import event_pb2 as schedule_dot_v1_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aschedule/v1/schedule.proto\x12\x0bschedule.v1\x1a\x17schedule/v1/event.proto\"\xb9\x07\n\x08Schedule\x12?\n customer_room_temp_setback_zone1\x18\x01 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12?\n customer_room_temp_setback_zone2\x18\x02 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12:\n\x1bsmart_room_temp_delta_zone1\x18\x03 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12:\n\x1bsmart_room_temp_delta_zone2\x18\x04 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x36\n\x17\x63ustomer_dhw_temp_delta\x18\x05 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x33\n\x14smart_dhw_temp_delta\x18\x06 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12$\n\x05\x62oost\x18\x07 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x30\n\x11\x63ustomer_dhw_temp\x18\x08 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12(\n\taway_mode\x18\t \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12.\n\x0f\x61nti_legionella\x18\n \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12<\n\x1dsmart_room_supply_delta_zone1\x18\x0b \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12<\n\x1dsmart_room_supply_delta_zone2\x18\x0c \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x31\n\x12smart_power_config\x18\r \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x36\n\x17\x63ustomer_charge_battery\x18\x0e \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12;\n\x1csmart_heat_curve_delta_zone1\x18\x0f \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12;\n\x1csmart_heat_curve_delta_zone2\x18\x10 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12)\n\nnight_mode\x18\x11 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x42\x08\n\x06group0Bi\n\x0bschedule.v1B\rScheduleProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.schedule_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013schedule.v1B\rScheduleProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_SCHEDULE']._serialized_start=69
  _globals['_SCHEDULE']._serialized_end=1022
# @@protoc_insertion_point(module_scope)