# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....state.v1 import state_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto\x12$device.heat_pump.telemetry.v1.ccv.v1\x1a%device/heat_pump/state/v1/state.proto\"\'\n\rEnergyBalance\x12\x16\n\x0e\x65nergy_balance\x18\x01 \x01(\x05\"\x93\x01\n\x12InlineHeaterStatus\x12\x11\n\tis_active\x18\x01 \x01(\x08\x12\"\n\x1ainline_heater_step1_active\x18\x02 \x01(\x08\x12\"\n\x1ainline_heater_step2_active\x18\x03 \x01(\x08\x12\"\n\x1ainline_heater_step3_active\x18\x04 \x01(\x08\"n\n\x15\x43irculationPumpStatus\x12\x14\n\x0cpump0_active\x18\x01 \x01(\x08\x12\x14\n\x0cpump1_active\x18\x02 \x01(\x08\x12\x14\n\x0cpump2_active\x18\x03 \x01(\x08\x12\x13\n\x0bpump0_speed\x18\x04 \x01(\x05\"\xcf\x01\n\x0bHeatingMode\x12\x1c\n\x10\x64\x65precated_state\x18\x01 \x01(\rB\x02\x18\x01\x12\x1e\n\x16\x61mbient_temp_avarage1h\x18\x02 \x01(\x02\x12\x1e\n\x16\x61mbient_temp_avarage3h\x18\x03 \x01(\x02\x12\x1f\n\x17\x61mbient_temp_avarage24h\x18\x04 \x01(\x02\x12\x41\n\x0fpump_mode_state\x18\x05 \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\"\xd8\x02\n\x11\x45nergyCalculation\x12\"\n\x1a\x63urrent_electrical_power_w\x18\x01 \x01(\r\x12!\n\x19\x65lectrical_energy_cum_kwh\x18\x02 \x01(\r\x12\x16\n\x0e\x63urrent_phase0\x18\x03 \x01(\x02\x12\x16\n\x0e\x63urrent_phase1\x18\x04 \x01(\x02\x12\x16\n\x0e\x63urrent_phase2\x18\x05 \x01(\x02\x12\x16\n\x0evoltage_phase0\x18\x06 \x01(\x02\x12\x16\n\x0evoltage_phase1\x18\x07 \x01(\x02\x12\x16\n\x0evoltage_phase2\x18\x08 \x01(\x02\x12 \n\x18\x65lectrical_energy_cum_wh\x18\t \x01(\r\x12\x1c\n\x14water_energy_cum_kwh\x18\n \x01(\r\x12\x1b\n\x13water_energy_cum_wh\x18\x0b \x01(\r\x12\x0f\n\x07\x63op_now\x18\x0c \x01(\x02\"\x96\x08\n\x0cMegmetStatus\x12\x17\n\x0frequested_state\x18\x01 \x01(\r\x12*\n\"compressor_need_percent_calculated\x18\x02 \x01(\x05\x12+\n#compressor_limit_percent_calculated\x18\x03 \x01(\x05\x12\x1e\n\x16\x63urrent_operation_mode\x18\x04 \x01(\r\x12\x18\n\x10\x61\x63_input_voltage\x18\x05 \x01(\r\x12\x18\n\x10\x61\x63_input_current\x18\x06 \x01(\r\x12\"\n\x1a\x63ompressor_frequency_limit\x18\x07 \x01(\r\x12 \n\x18\x63ompressor_running_speed\x18\x08 \x01(\r\x12\x1a\n\x12\x64\x63_fan_speed_limit\x18\t \x01(\r\x12\x1d\n\x15\x64\x63_fan1_running_speed\x18\n \x01(\r\x12\x1d\n\x15\x64\x63_fan2_running_speed\x18\x0b \x01(\r\x12\x10\n\x08\x65\x65v_step\x18\x0c \x01(\r\x12\x16\n\x0erelay_feedback\x18\r \x01(\r\x12\x1b\n\x13\x61mbient_temperature\x18\x0e \x01(\x02\x12#\n\x1b\x65vaporator_coil_temperature\x18\x0f \x01(\x02\x12!\n\x19gas_discharge_temperature\x18\x10 \x01(\x02\x12\x1e\n\x16gas_return_temperature\x18\x11 \x01(\x02\x12\x17\n\x0f\x63ompressor_code\x18\x12 \x01(\r\x12\x1f\n\x17outdoor_unit_dip_switch\x18\x13 \x01(\r\x12\x1b\n\x13\x65vaporator_pressure\x18\x14 \x01(\x02\x12\x1a\n\x12\x63ondenser_pressure\x18\x15 \x01(\x02\x12\x1f\n\x17outdoor_unit_defrosting\x18\x16 \x01(\x08\x12(\n outdoor_unit_pcb_program_version\x18\x17 \x01(\r\x12\'\n\x1foutdoor_unit_pcb_eeprom_version\x18\x18 \x01(\r\x12&\n\x1emain_control_board_item_number\x18\x19 \x01(\r\x12\x1e\n\x16\x63ondensing_temperature\x18\x1a \x01(\x02\x12\x1f\n\x17\x65vaporating_temperature\x18\x1b \x01(\x02\x12\x1f\n\x17inlet_water_temperature\x18\x1c \x01(\x02\x12 \n\x18outlet_water_temperature\x18\x1d \x01(\x02\x12\x1e\n\x16inner_coil_temperature\x18\x1e \x01(\x02\x12\x1a\n\x12outdoor_unit_model\x18\x1f \x01(\t\x12\"\n\x1aoutdoor_unit_serial_number\x18  \x01(\t\"\xbf\x01\n\tSmartGrid\x12\x44\n\x05state\x18\x01 \x01(\x0e\x32\x35.device.heat_pump.telemetry.v1.ccv.v1.SmartGrid.State\"l\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_BLOCKED\x10\x01\x12\x10\n\x0cSTATE_NORMAL\x10\x02\x12\x14\n\x10STATE_ENCOURAGED\x10\x03\x12\x11\n\rSTATE_ORDERED\x10\x04\"\x94\x03\n\x0bValveStatus\x12]\n\x19\x64hw_heating_cooling_valve\x18\x01 \x01(\x0e\x32:.device.heat_pump.telemetry.v1.ccv.v1.ValveStatus.Position\x12\x1d\n\x15mixing_valve1_opening\x18\x02 \x01(\x08\x12\x1d\n\x15mixing_valve2_opening\x18\x03 \x01(\x08\x12\x1d\n\x15mixing_valve1_closing\x18\x04 \x01(\x08\x12\x1d\n\x15mixing_valve2_closing\x18\x05 \x01(\x08\x12)\n!mixing_valve1_calculated_position\x18\x06 \x01(\x05\x12)\n!mixing_valve2_calculated_position\x18\x07 \x01(\x05\"T\n\x08Position\x12\x18\n\x14POSITION_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOSITION_DHW\x10\x01\x12\x1c\n\x18POSITION_HEATING_COOLING\x10\x02\"y\n\x13\x43\x61lculatedSetpoints\x12\x0e\n\x06supply\x18\x01 \x01(\x02\x12\x14\n\x0csupply_zone1\x18\x02 \x01(\x02\x12\x14\n\x0csupply_zone2\x18\x03 \x01(\x02\x12\x12\n\ntemp_room1\x18\x04 \x01(\x02\x12\x12\n\ntemp_room2\x18\x05 \x01(\x02\"\xe7\x03\n\x0cSensorValues\x12(\n outdoor_unit_ambient_temperature\x18\x01 \x01(\x02\x12\'\n\x1foutdoor_unit_supply_temperature\x18\x02 \x01(\x02\x12\'\n\x1foutdoor_unit_return_temperature\x18\x03 \x01(\x02\x12+\n#outdoor_unit_inner_coil_temperature\x18\x04 \x01(\x02\x12(\n indoor_unit_dhw_tank_temperature\x18\x05 \x01(\x02\x12&\n\x1eindoor_unit_supply_temperature\x18\x06 \x01(\x02\x12,\n$indoor_unit_supply_temperature_zone1\x18\x07 \x01(\x02\x12,\n$indoor_unit_supply_temperature_zone2\x18\x08 \x01(\x02\x12*\n\"indoor_unit_room_temperature_zone1\x18\t \x01(\x02\x12*\n\"indoor_unit_room_temperature_zone2\x18\n \x01(\x02\x12\x13\n\x0b\x66low_meter1\x18\x0b \x01(\x02\x12\x13\n\x0b\x66low_meter2\x18\x0c \x01(\x02\x42\xeb\x01\n$device.heat_pump.telemetry.v1.ccv.v1B\x12TelemetryDataProtoP\x01\xa2\x02\x03TVC\xaa\x02#Device.HeatPump.Telemetry.V1.Ccv.V1\xca\x02#Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\xe2\x02/Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\\GPBMetadata\xea\x02(Device::HeatPump::Telemetry::V1::Ccv::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.telemetry.v1.ccv.v1.telemetry_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$device.heat_pump.telemetry.v1.ccv.v1B\022TelemetryDataProtoP\001\242\002\003TVC\252\002#Device.HeatPump.Telemetry.V1.Ccv.V1\312\002#Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\342\002/Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\\GPBMetadata\352\002(Device::HeatPump::Telemetry::V1::Ccv::V1'
  _globals['_HEATINGMODE'].fields_by_name['deprecated_state']._loaded_options = None
  _globals['_HEATINGMODE'].fields_by_name['deprecated_state']._serialized_options = b'\030\001'
  _globals['_ENERGYBALANCE']._serialized_start=138
  _globals['_ENERGYBALANCE']._serialized_end=177
  _globals['_INLINEHEATERSTATUS']._serialized_start=180
  _globals['_INLINEHEATERSTATUS']._serialized_end=327
  _globals['_CIRCULATIONPUMPSTATUS']._serialized_start=329
  _globals['_CIRCULATIONPUMPSTATUS']._serialized_end=439
  _globals['_HEATINGMODE']._serialized_start=442
  _globals['_HEATINGMODE']._serialized_end=649
  _globals['_ENERGYCALCULATION']._serialized_start=652
  _globals['_ENERGYCALCULATION']._serialized_end=996
  _globals['_MEGMETSTATUS']._serialized_start=999
  _globals['_MEGMETSTATUS']._serialized_end=2045
  _globals['_SMARTGRID']._serialized_start=2048
  _globals['_SMARTGRID']._serialized_end=2239
  _globals['_SMARTGRID_STATE']._serialized_start=2131
  _globals['_SMARTGRID_STATE']._serialized_end=2239
  _globals['_VALVESTATUS']._serialized_start=2242
  _globals['_VALVESTATUS']._serialized_end=2646
  _globals['_VALVESTATUS_POSITION']._serialized_start=2562
  _globals['_VALVESTATUS_POSITION']._serialized_end=2646
  _globals['_CALCULATEDSETPOINTS']._serialized_start=2648
  _globals['_CALCULATEDSETPOINTS']._serialized_end=2769
  _globals['_SENSORVALUES']._serialized_start=2772
  _globals['_SENSORVALUES']._serialized_end=3259
# @@protoc_insertion_point(module_scope)