# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/power.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/state/v1/power.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%device/heat_pump/state/v1/power.proto\x12\x19\x64\x65vice.heat_pump.state.v1\"#\n\x12\x43urrentTransformer\x12\r\n\x05ratio\x18\x01 \x01(\r\"\xa2\x01\n\x17\x43urrentTransformerState\x12:\n\nscan_state\x18\x01 \x01(\x0e\x32&.device.heat_pump.state.v1.CtScanState\x12K\n\x14\x63urrent_transformers\x18\x02 \x03(\x0b\x32-.device.heat_pump.state.v1.CurrentTransformer\"\x1e\n\x08Inverter\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\x1d\n\x07\x42\x61ttery\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"#\n\rPhotovoltaics\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\xbd\x01\n\x0cPowerDevices\x12\x35\n\x08inverter\x18\x03 \x03(\x0b\x32#.device.heat_pump.state.v1.Inverter\x12?\n\rphotovoltaics\x18\x04 \x03(\x0b\x32(.device.heat_pump.state.v1.Photovoltaics\x12\x35\n\tbatteries\x18\x05 \x03(\x0b\x32\".device.heat_pump.state.v1.Battery\"\xda\x01\n\nPowerState\x12\x1a\n\x12paired_core_serial\x18\x01 \x01(\t\x12\x1f\n\x17paired_core_app_version\x18\x02 \x01(\t\x12\x38\n\x07\x64\x65vices\x18\x03 \x01(\x0b\x32\'.device.heat_pump.state.v1.PowerDevices\x12U\n\x19\x63urrent_transformer_state\x18\x04 \x01(\x0b\x32\x32.device.heat_pump.state.v1.CurrentTransformerState*h\n\x0b\x43tScanState\x12\x1d\n\x19\x43T_SCAN_STATE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43T_SCAN_STATE_NOT_SCANNING\x10\x01\x12\x1a\n\x16\x43T_SCAN_STATE_SCANNING\x10\x02\x42\xaa\x01\n\x19\x64\x65vice.heat_pump.state.v1B\nPowerProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.power_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031device.heat_pump.state.v1B\nPowerProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_CTSCANSTATE']._serialized_start=783
  _globals['_CTSCANSTATE']._serialized_end=887
  _globals['_CURRENTTRANSFORMER']._serialized_start=68
  _globals['_CURRENTTRANSFORMER']._serialized_end=103
  _globals['_CURRENTTRANSFORMERSTATE']._serialized_start=106
  _globals['_CURRENTTRANSFORMERSTATE']._serialized_end=268
  _globals['_INVERTER']._serialized_start=270
  _globals['_INVERTER']._serialized_end=300
  _globals['_BATTERY']._serialized_start=302
  _globals['_BATTERY']._serialized_end=331
  _globals['_PHOTOVOLTAICS']._serialized_start=333
  _globals['_PHOTOVOLTAICS']._serialized_end=368
  _globals['_POWERDEVICES']._serialized_start=371
  _globals['_POWERDEVICES']._serialized_end=560
  _globals['_POWERSTATE']._serialized_start=563
  _globals['_POWERSTATE']._serialized_end=781
# @@protoc_insertion_point(module_scope)